@@ -5,6 +5,7 @@
 #pragma once
 
 #include <chrono>
+#include <cstddef>
 #include <memory>
 #include <tuple>
 #include <utility>
@@ -78,6 +79,32 @@ constexpr bool has_static_apply_v = has_static_apply<T, Inspector, Obj>::value;
 
 // -- loading ------------------------------------------------------------------
 
+// Converts a setter that returns void, error or bool to a sync function object
+// taking no arguments that always returns a bool.
+template <class Inspector, class Set, class ValueType>
+auto bind_setter(Inspector& f, Set& set, ValueType& tmp) {
+  using set_result_type = decltype(set(std::move(tmp)));
+  if constexpr (std::is_same<set_result_type, bool>::value) {
+    return [&] { return set(std::move(tmp)); };
+  } else if constexpr (std::is_same<set_result_type, error>::value) {
+    return [&] {
+      if (auto err = set(std::move(tmp)); !err) {
+        return true;
+      } else {
+        f.set_error(std::move(err));
+        return false;
+      }
+    };
+  } else {
+    static_assert(std::is_same<set_result_type, void>::value,
+                  "a setter must return caf::error, bool or void");
+    return [&] {
+      set(std::move(tmp));
+      return true;
+    };
+  }
+}
+
 // TODO: remove with CAF 0.19
 template <class Inspector, class T>
 [[deprecated("please provide apply instead of apply_object/apply_value")]] //
@@ -261,7 +288,15 @@ bool save(Inspector& f, T& x) {
 
 template <class Inspector, class T>
 bool save(Inspector& f, const T& x) {
-  return save(f, as_mutable_ref(x), inspect_access_type<Inspector, T>());
+  if constexpr (!std::is_function<T>::value) {
+    return save(f, as_mutable_ref(x), inspect_access_type<Inspector, T>());
+  } else {
+    // Only inspector such as the stringification_inspector are going to accept
+    // function pointers. Most other inspectors are going to trigger a static
+    // assertion when passing `inspector_access_type::none`.
+    auto fptr = std::add_pointer_t<T>{x};
+    return save(f, fptr, inspector_access_type::none{});
+  }
 }
 
 template <class Inspector, class T>
@@ -390,9 +425,8 @@ struct optional_inspector_access {
                          container_type& x, IsValid& is_valid,
                          SyncValue& sync_value) {
     traits::emplace(x);
-    auto set_x = [&] { return sync_value(); };
     auto reset = [&x] { x.reset(); };
-    return detail::load_field(f, field_name, *x, is_valid, set_x, reset);
+    return detail::load_field(f, field_name, *x, is_valid, sync_value, reset);
   }
 
   template <class Inspector, class IsValid, class SyncValue, class SetFallback>
@@ -400,8 +434,8 @@ struct optional_inspector_access {
                          container_type& x, IsValid& is_valid,
                          SyncValue& sync_value, SetFallback& set_fallback) {
     traits::emplace(x);
-    auto set_x = [&] { return sync_value(); };
-    return detail::load_field(f, field_name, *x, is_valid, set_x, set_fallback);
+    return detail::load_field(f, field_name, *x, is_valid, sync_value,
+                              set_fallback);
   }
 };
 
@@ -442,6 +476,23 @@ struct inspector_access<std::unique_ptr<error::data>>
   // nop
 };
 
+// -- inspection support for std::byte -----------------------------------------
+
+#ifdef __cpp_lib_byte
+
+template <>
+struct inspector_access<std::byte> : inspector_access_base<std::byte> {
+  template <class Inspector>
+  [[nodiscard]] static bool apply(Inspector& f, std::byte& x) {
+    using integer_type = std::underlying_type_t<std::byte>;
+    auto get = [&x] { return static_cast<integer_type>(x); };
+    auto set = [&x](integer_type val) { x = static_cast<std::byte>(val); };
+    return f.apply(get, set);
+  }
+};
+
+#endif
+
 // -- inspection support for variant<Ts...> ------------------------------------
 
 template <class T>
@@ -575,8 +626,9 @@ struct variant_inspector_access {
       return false;
     }
     if (!sync_value()) {
-      f.emplace_error(sec::field_value_synchronization_failed,
-                      to_string(field_name));
+      if (!f.get_error())
+        f.emplace_error(sec::field_value_synchronization_failed,
+                        to_string(field_name));
       return false;
     }
     return f.end_field();
@@ -605,8 +657,9 @@ struct variant_inspector_access {
         return false;
       }
       if (!sync_value()) {
-        f.emplace_error(sec::field_value_synchronization_failed,
-                        to_string(field_name));
+        if (!f.get_error())
+          f.emplace_error(sec::field_value_synchronization_failed,
+                          to_string(field_name));
         return false;
       }
     } else {
@@ -737,10 +790,7 @@ struct inspector_access<
         detail::print(str, x);
         return str;
       };
-      auto set = [&x](std::string str) {
-        auto err = detail::parse(str, x);
-        return !err;
-      };
+      auto set = [&x](std::string str) { return detail::parse(str, x); };
       return f.apply(get, set);
     } else {
       using rep_type = typename Duration::rep;
