@@ -191,7 +191,7 @@ const char* actor_system::module::name() const noexcept {
     case openssl_manager:
       return "openssl-manager";
     case network_manager:
-      return "metwork-manager";
+      return "network-manager";
     default:
       return "???";
   }
@@ -277,6 +277,9 @@ actor_system::actor_system(actor_system_config& cfg)
     tracing_context_(cfg.tracing_context),
     private_threads_(this) {
   CAF_SET_LOGGER_SYS(this);
+  meta_objects_guard_ = detail::global_meta_objects_guard();
+  if (!meta_objects_guard_)
+    CAF_CRITICAL("unable to obtain the global meta objects guard");
   for (auto& hook : cfg.thread_hooks_)
     hook->init(*this);
   // Cache some configuration parameters for faster lookups at runtime.
@@ -381,8 +384,6 @@ actor_system::~actor_system() {
     };
     drop(spawn_serv_);
     drop(config_serv_);
-    registry_.erase("SpawnServ");
-    registry_.erase("ConfigServ");
     // group module is the first one, relies on MM
     groups_.stop();
     // stop modules in reverse order
@@ -455,7 +456,7 @@ bool actor_system::has_network_manager() const noexcept {
 net::middleman& actor_system::network_manager() {
   auto& clptr = modules_[module::network_manager];
   if (!clptr)
-    CAF_RAISE_ERROR("cannot access openssl manager: module not loaded");
+    CAF_RAISE_ERROR("cannot access network manager: module not loaded");
   return *reinterpret_cast<net::middleman*>(clptr->subtype_ptr());
 }
 
