@@ -16,17 +16,14 @@
 
 #define _GNU_SOURCE
 #include <poll.h>
-#include <pthread.h>
-#include <sys/types.h>
+#include <signal.h>
+#include <sys/prctl.h>
 #include <sys/resource.h>
+
 #include "../common/private.h"
 
 #define MONITORING_THREAD_SIGNAL  (SIGRTMIN + 1)
 
-
-//XXX-FIXME TEMP
-const struct filter evfilt_proc = EVFILT_NOTIMPL;
-
 /*
  * Per-thread epoll event buffer used to ferry data between
  * kevent_wait() and kevent_copyout().
@@ -66,18 +63,6 @@ static unsigned int *fd_use_cnt;
 
 static int nb_max_fd;
 
-const struct kqueue_vtable kqops = {
-    .kqueue_init        = linux_kqueue_init,
-    .kqueue_free        = linux_kqueue_free,
-    .kevent_wait        = linux_kevent_wait,
-    .kevent_copyout     = linux_kevent_copyout,
-    .eventfd_init       = linux_eventfd_init,
-    .eventfd_close      = linux_eventfd_close,
-    .eventfd_raise      = linux_eventfd_raise,
-    .eventfd_lower      = linux_eventfd_lower,
-    .eventfd_descriptor = linux_eventfd_descriptor,
-};
-
 static void
 linux_kqueue_cleanup(struct kqueue *kq);
 
@@ -193,6 +178,11 @@ monitoring_thread_loop(void *arg)
 
     sigset_t monitoring_sig_set;
 
+    /* Set the thread's name to something descriptive so it shows up in gdb,
+     * etc. glibc >= 2.1.2 supports pthread_setname_np, but this is a safer way
+     * to do it for backwards compatibility. Max name length is 16 bytes. */
+    prctl(PR_SET_NAME, "libkqueue_mon", 0, 0, 0);
+
     nb_max_fd = get_fd_limit();
 
     sigemptyset(&monitoring_sig_set);
@@ -273,11 +263,10 @@ linux_kqueue_start_thread(void)
     pthread_mutex_unlock(&mt_mtx);
 }
 
-int
+static int
 linux_kqueue_init(struct kqueue *kq)
 {
     struct f_owner_ex sig_owner;
-    int flags;
 
     kq->epollfd = epoll_create(1);
     if (kq->epollfd < 0) {
@@ -319,10 +308,13 @@ linux_kqueue_init(struct kqueue *kq)
     }
 
     /*
-     * Ensure pipe ends are non-blocking so that there's
-     * no chance of them delaying close().
+     * O_NONBLOCK - Ensure pipe ends are non-blocking so that
+     * there's no chance of them delaying close().
+     *
+     * O_ASYNC - Raise a SIGIO signal if the file descriptor
+     * becomes readable or is closed.
      */
-    if ((fcntl(kq->pipefd[0], F_SETFL, O_NONBLOCK) < 0) ||
+    if ((fcntl(kq->pipefd[0], F_SETFL, O_NONBLOCK | O_ASYNC ) < 0) ||
         (fcntl(kq->pipefd[1], F_SETFL, O_NONBLOCK) < 0)) {
         dbg_perror("fcntl(2)");
         goto error;
@@ -330,17 +322,6 @@ linux_kqueue_init(struct kqueue *kq)
 
     kq->kq_id = kq->pipefd[1];
 
-    /*
-     * Setting O_ASYNC means a signal (SIGIO) will be sent
-     * whenever I/O is possible OR when the other end of the
-     * pipe has been closed.
-     */
-    flags = fcntl(kq->pipefd[0], F_GETFL, 0);
-    if (fcntl(kq->pipefd[0], F_SETFL, flags | O_ASYNC) < 0) {
-        dbg_printf("fd=%i - failed setting FSETFL O_ASYNC (%i): %s", kq->pipefd[0], flags, strerror(errno));
-        goto error;
-    }
-
     /*
      * SIGIO may be used by the application, so we use F_SETSIG
      * to change the signal sent to one in the realtime range
@@ -459,7 +440,7 @@ linux_kqueue_cleanup(struct kqueue *kq)
  * KQ fd is in use, and we shouldn't attempt to free it if we
  * receive a signal in the monitoring thread.
  */
-void
+static void
 linux_kqueue_free(struct kqueue *kq)
 {
     linux_kqueue_cleanup(kq);
@@ -506,7 +487,7 @@ linux_kevent_wait_hires(
     return (n);
 }
 
-int
+static int
 linux_kevent_wait(struct kqueue *kq, int nevents, const struct timespec *ts)
 {
     int timeout, nret;
@@ -538,13 +519,12 @@ linux_kevent_wait(struct kqueue *kq, int nevents, const struct timespec *ts)
     return (nret);
 }
 
-static inline int linux_kevent_copyout_ev(struct kevent **el_p, struct epoll_event *ev,
+static inline int linux_kevent_copyout_ev(struct kevent *el, int nevents, struct epoll_event *ev,
                                           struct filter *filt, struct knote *kn)
 {
     int rv;
-    struct kevent *el = *el_p;
 
-    rv = filt->kf_copyout(el, kn, ev);
+    rv = filt->kf_copyout(el, nevents, filt, kn, ev);
     if (unlikely(rv < 0)) {
         dbg_puts("knote_copyout failed");
         assert(0);
@@ -552,22 +532,14 @@ static inline int linux_kevent_copyout_ev(struct kevent **el_p, struct epoll_eve
     }
 
     /*
-     *    Advance to the next el entry
+     * Don't emit bad events...
+     *
+     * Fixme - We shouldn't be emitting bad events
+     * in the first place?
      */
-    if (likely(el->filter != 0)) {
-        (*el_p)++;
-    } else {
+    if (unlikely(el->filter == 0)) {
         dbg_puts("spurious wakeup, discarding event");
-    }
-
-    /*
-     * Certain flags cause the associated knote to be deleted
-     * or disabled.
-     */
-    if (el->flags & EV_DISPATCH)
-        knote_disable(filt, kn); //FIXME: Error checking
-    if (el->flags & EV_ONESHOT) {
-        knote_delete(filt, kn); //FIXME: Error checking
+        rv = 0;
     }
 
     return rv;
@@ -585,27 +557,33 @@ linux_kevent_copyout(struct kqueue *kq, int nready, struct kevent *el, int neven
         int                   rv;
 
         if (!epoll_udata) {
-            dbg_puts("event has no filter, skipping...");
+            dbg_puts("event has no knote, skipping..."); /* Forgot to call KN_UDATA()? */
             continue;
         }
 
-        switch (epoll_udata->ud_type) {
         /*
          * epoll event is associated with a single filter
-         * so we just have the one knote.
+         * so we just have one knote per event.
+         *
+         * As different filters store pointers to different
+         * structures, we need to examine ud_type to figure
+         * out what epoll_data contains.
          */
+        switch (epoll_udata->ud_type) {
         case EPOLL_UDATA_KNOTE:
         {
             struct knote *kn = epoll_udata->ud_kn;
 
+            assert(kn);
             if (el_p >= el_end) {
             oos:
                 dbg_printf("no more available kevent slots, used %zu", el_p - el);
                 goto done;
             }
 
-            rv = linux_kevent_copyout_ev(&el_p, ev, &kq->kq_filt[~(kn->kev.filter)], kn);
+            rv = linux_kevent_copyout_ev(el_p, (el_end - el_p), ev, &kq->kq_filt[~(kn->kev.filter)], kn);
             if (rv < 0) goto done;
+            el_p += rv;
         }
             break;
 
@@ -615,9 +593,10 @@ linux_kevent_copyout(struct kqueue *kq, int nready, struct kevent *el, int neven
          */
         case EPOLL_UDATA_FD_STATE:
         {
-            struct fd_state      *fds = epoll_udata->ud_fds;
-            struct knote         *kn;
+            struct fd_state   *fds = epoll_udata->ud_fds;
+            struct knote      *kn;
 
+            assert(fds);
             /*
              *    FD is readable
              */
@@ -634,8 +613,9 @@ linux_kevent_copyout(struct kqueue *kq, int nready, struct kevent *el, int neven
                  */
                 assert(kn);
 
-                rv = linux_kevent_copyout_ev(&el_p, ev, &kq->kq_filt[~(kn->kev.filter)], kn);
+                rv = linux_kevent_copyout_ev(el_p, (el_end - el_p), ev, &kq->kq_filt[~(kn->kev.filter)], kn);
                 if (rv < 0) goto done;
+                el_p += rv;
             }
 
             /*
@@ -648,12 +628,27 @@ linux_kevent_copyout(struct kqueue *kq, int nready, struct kevent *el, int neven
 
                 assert(kn);    /* We shouldn't receive events we didn't request */
 
-                rv = linux_kevent_copyout_ev(&el_p, ev, &kq->kq_filt[~(kn->kev.filter)], kn);
+                rv = linux_kevent_copyout_ev(el_p, (el_end - el_p), ev, &kq->kq_filt[~(kn->kev.filter)], kn);
                 if (rv < 0) goto done;
+                el_p += rv;
             }
         }
             break;
 
+        case EPOLL_UDATA_EVENT_FD:
+        {
+            struct eventfd    *efd = epoll_udata->ud_efd;
+
+            assert(efd);
+
+            dbg_printf("eventfd=%u - received event", (unsigned int)efd->ef_id);
+
+            rv = linux_kevent_copyout_ev(el_p, (el_end - el_p), ev, efd->ef_filt, NULL);
+            if (rv < 0) goto done;
+            el_p += rv;
+            break;
+        }
+
         /*
          *    Bad udata value. Maybe use after free?
          */
@@ -666,44 +661,62 @@ linux_kevent_copyout(struct kqueue *kq, int nready, struct kevent *el, int neven
 done:
     return el_p - el;
 }
+
 int
-linux_eventfd_init(struct eventfd *e)
+linux_eventfd_register(struct kqueue *kq, struct eventfd *efd)
+{
+    EVENTFD_UDATA(efd); /* setup udata for the efd */
+
+    if (epoll_ctl(kq->epollfd, EPOLL_CTL_ADD, kqops.eventfd_descriptor(efd), EPOLL_EV_EVENTFD(EPOLLIN, efd)) < 0) {
+        dbg_perror("epoll_ctl(2)");
+        return -1;
+    }
+
+    return 0;
+}
+
+void
+linux_eventfd_unregister(struct kqueue *kq, struct eventfd *efd)
+{
+    if (epoll_ctl(kq->epollfd, EPOLL_CTL_DEL, kqops.eventfd_descriptor(efd), NULL) < 0)
+        dbg_perror("epoll_ctl(2)");
+}
+
+static int
+linux_eventfd_init(struct eventfd *efd, struct filter *filt)
 {
     int evfd;
 
-    evfd = eventfd(0, 0);
+    evfd = eventfd(0, EFD_NONBLOCK);
     if (evfd < 0) {
         dbg_perror("eventfd");
         return (-1);
     }
-    if (fcntl(evfd, F_SETFL, O_NONBLOCK) < 0) {
-        dbg_perror("fcntl");
-        if (close(evfd) < 0)
-            dbg_perror("close(2)");
-        return (-1);
-    }
-    e->ef_id = evfd;
+    dbg_printf("eventfd=%i - created", evfd);
+    efd->ef_id = evfd;
+    efd->ef_filt = filt;
 
     return (0);
 }
 
-void
-linux_eventfd_close(struct eventfd *e)
+static void
+linux_eventfd_close(struct eventfd *efd)
 {
-    if (close(e->ef_id) < 0)
+    dbg_printf("eventfd=%i - closed", efd->ef_id);
+    if (close(efd->ef_id) < 0)
         dbg_perror("close(2)");
-    e->ef_id = -1;
+    efd->ef_id = -1;
 }
 
-int
-linux_eventfd_raise(struct eventfd *e)
+static int
+linux_eventfd_raise(struct eventfd *efd)
 {
     uint64_t counter;
     int rv = 0;
 
-    dbg_puts("raising event level");
+    dbg_printf("eventfd=%i - raising event level", efd->ef_id);
     counter = 1;
-    if (write(e->ef_id, &counter, sizeof(counter)) < 0) {
+    if (write(efd->ef_id, &counter, sizeof(counter)) < 0) {
         switch (errno) {
         case EAGAIN:
             /* Not considered an error */
@@ -721,16 +734,25 @@ linux_eventfd_raise(struct eventfd *e)
     return (rv);
 }
 
-int
-linux_eventfd_lower(struct eventfd *e)
+static int
+linux_eventfd_lower(struct eventfd *efd)
 {
     uint64_t cur;
     ssize_t n;
     int rv = 0;
 
-    /* Reset the counter */
-    dbg_puts("lowering event level");
-    n = read(e->ef_id, &cur, sizeof(cur));
+    /*
+     * Reset the counter
+     * Because we're not using EFD_SEMPAHOR the level
+     * state of the eventfd is cleared.
+     *
+     * Thus if there were multiple calls to
+     * linux_eventfd_raise, and a single call to
+     * linux_eventfd_lower, the eventfd state would
+     * still be lowered.
+     */
+    dbg_printf("eventfd=%i - lowering event level", efd->ef_id);
+    n = read(efd->ef_id, &cur, sizeof(cur));
     if (n < 0) {
         switch (errno) {
         case EAGAIN:
@@ -753,10 +775,10 @@ linux_eventfd_lower(struct eventfd *e)
     return (rv);
 }
 
-int
-linux_eventfd_descriptor(struct eventfd *e)
+static int
+linux_eventfd_descriptor(struct eventfd *efd)
 {
-    return (e->ef_id);
+    return (efd->ef_id);
 }
 
 /** Determine what type of file descriptor the knote describes
@@ -829,7 +851,7 @@ linux_get_descriptor_type(struct knote *kn)
             dbg_printf("fd=%i is a socket", fd);
             break; /* deferred type determination */
 
-        case 0:	/* seen with eventfd */
+        case 0: /* seen with eventfd */
             dbg_printf("fd=%i fstat() provided no S_IFMT flags, treating fd as passive socket", fd);
             kn->kn_flags |= KNFL_SOCKET;
             kn->kn_flags |= KNFL_SOCKET_PASSIVE;
@@ -1349,3 +1371,17 @@ linux_fd_to_path(char *buf, size_t bufsz, int fd)
     memset(buf, 0, bufsz);
     return (readlink(path, buf, bufsz));
 }
+
+const struct kqueue_vtable kqops = {
+    .kqueue_init        = linux_kqueue_init,
+    .kqueue_free        = linux_kqueue_free,
+    .kevent_wait        = linux_kevent_wait,
+    .kevent_copyout     = linux_kevent_copyout,
+    .eventfd_register   = linux_eventfd_register,
+    .eventfd_unregister = linux_eventfd_unregister,
+    .eventfd_init       = linux_eventfd_init,
+    .eventfd_close      = linux_eventfd_close,
+    .eventfd_raise      = linux_eventfd_raise,
+    .eventfd_lower      = linux_eventfd_lower,
+    .eventfd_descriptor = linux_eventfd_descriptor,
+};
