@@ -2,16 +2,18 @@
 
 #pragma once
 
-namespace zeek::detail {
+namespace zeek::detail
+	{
 
 class Expr;
 
 // Automatic displays: display these at each stoppage.
-class DbgDisplay {
+class DbgDisplay
+	{
 public:
 	DbgDisplay(Expr* expr_to_display);
 
-	bool IsEnabled()	{ return enabled; }
+	bool IsEnabled() { return enabled; }
 	bool SetEnable(bool do_enable)
 		{
 		bool old_value = enabled;
@@ -19,11 +21,11 @@ public:
 		return old_value;
 		}
 
-	const Expr* Expression() const	{ return expression; }
+	const Expr* Expression() const { return expression; }
 
 protected:
 	bool enabled;
 	Expr* expression;
 	};
 
-} // namespace zeek::detail
+	} // namespace zeek::detail
