@@ -4,13 +4,18 @@
 
 #include "zeek/util.h"
 
-namespace zeek { class Obj; }
+namespace zeek
+	{
+class Obj;
+	}
 
-namespace zeek::detail {
+namespace zeek::detail
+	{
 
 class Expr;
 
-class DbgWatch {
+class DbgWatch
+	{
 public:
 	explicit DbgWatch(Obj* var_to_watch);
 	explicit DbgWatch(Expr* expr_to_watch);
@@ -19,6 +24,6 @@ public:
 protected:
 	Obj* var;
 	Expr* expr;
-};
+	};
 
-} // namespace zeek::detail
+	} // namespace zeek::detail
