@@ -1,22 +1,24 @@
 // See the file "COPYING" in the main distribution directory for copyright.
 
-#include "zeek/zeek-config.h"
 #include "zeek/Desc.h"
 
-#include <stdlib.h>
-#include <string.h>
+#include "zeek/zeek-config.h"
+
 #include <errno.h>
 #include <math.h>
+#include <stdlib.h>
+#include <string.h>
 
+#include "zeek/3rdparty/ConvertUTF.h"
 #include "zeek/File.h"
-#include "zeek/Reporter.h"
-#include "zeek/ConvertUTF.h"
 #include "zeek/IPAddr.h"
+#include "zeek/Reporter.h"
 
 #define DEFAULT_SIZE 128
 #define SLOP 10
 
-namespace zeek {
+namespace zeek
+	{
 
 ODesc::ODesc(DescType t, File* arg_f)
 	{
@@ -28,7 +30,7 @@ ODesc::ODesc(DescType t, File* arg_f)
 		{
 		size = DEFAULT_SIZE;
 		base = util::safe_malloc(size);
-		((char*) base)[0] = '\0';
+		((char*)base)[0] = '\0';
 		offset = 0;
 		}
 	else
@@ -64,7 +66,7 @@ void ODesc::EnableEscaping()
 	escape = true;
 	}
 
-void ODesc::EnableUTF8 ()
+void ODesc::EnableUTF8()
 	{
 	utf8 = true;
 	}
@@ -93,12 +95,11 @@ void ODesc::Add(const char* s, int do_indent)
 	{
 	unsigned int n = strlen(s);
 
-	if ( do_indent && IsReadable() && offset > 0 &&
-	     ((const char*) base)[offset - 1] == '\n' )
+	if ( do_indent && IsReadable() && offset > 0 && ((const char*)base)[offset - 1] == '\n' )
 		Indent();
 
 	if ( IsBinary() )
-		AddBytes(s, n+1);
+		AddBytes(s, n + 1);
 	else
 		AddBytes(s, n);
 	}
@@ -169,13 +170,12 @@ void ODesc::Add(double d, bool no_exp)
 		Add(tmp);
 
 		auto approx_equal = [](double a, double b, double tolerance = 1e-6) -> bool
-			{
+		{
 			auto v = a - b;
 			return v < 0 ? -v < tolerance : v < tolerance;
-			};
+		};
 
-		if ( approx_equal(d, nearbyint(d), 1e-9) &&
-		     isfinite(d) && ! strchr(tmp, 'e') )
+		if ( approx_equal(d, nearbyint(d), 1e-9) && isfinite(d) && ! strchr(tmp, 'e') )
 			// disambiguate from integer
 			Add(".0");
 		}
@@ -210,7 +210,7 @@ void ODesc::AddBytes(const String* s)
 			{
 			const char* str = s->Render(String::EXPANDED_STRING);
 			Add(str);
-			delete [] str;
+			delete[] str;
 			}
 		}
 	else
@@ -251,11 +251,8 @@ size_t ODesc::StartsWithEscapeSequence(const char* start, const char* end)
 	if ( escape_sequences.empty() )
 		return 0;
 
-	escape_set::const_iterator it;
-
-	for ( it = escape_sequences.begin(); it != escape_sequences.end(); ++it )
+	for ( const auto& esc_str : escape_sequences )
 		{
-		const std::string& esc_str = *it;
 		size_t esc_len = esc_str.length();
 
 		if ( start + esc_len > end )
@@ -270,7 +267,7 @@ size_t ODesc::StartsWithEscapeSequence(const char* start, const char* end)
 
 std::pair<const char*, size_t> ODesc::FirstEscapeLoc(const char* bytes, size_t n)
 	{
-	typedef std::pair<const char*, size_t> escape_pos;
+	using escape_pos = std::pair<const char*, size_t>;
 
 	if ( IsBinary() )
 		return escape_pos(0, 0);
@@ -289,59 +286,49 @@ std::pair<const char*, size_t> ODesc::FirstEscapeLoc(const char* bytes, size_t n
 
 		if ( len )
 			return escape_pos(bytes + i, len);
-
-		if ( ! printable && utf8 )
-			{
-			size_t utf_found = getNumBytesForUTF8(bytes[i]);
-
-			if ( utf_found == 1 )
-				return escape_pos(bytes + i, 1);
-
-			if ( i + utf_found > n )
-				// Don't know if this is even meant to be a utf8 encoding,
-				// since there's not enough bytes left to check it's a valid
-				// sequence, so maybe safest to just move up by one instead
-				// of escaping the entire remainder.
-				return escape_pos(bytes + i, 1);
-
-			if ( isLegalUTF8Sequence(reinterpret_cast<const unsigned char *>(bytes + i),
-			                         reinterpret_cast<const unsigned char *>(bytes + i + utf_found)) )
-				{
-				i += utf_found - 1;
-				continue;
-				}
-
-			return escape_pos(bytes + i, 1);
-			}
 		}
 
-	return escape_pos(0, 0);
+	return escape_pos(nullptr, 0);
 	}
 
 void ODesc::AddBytes(const void* bytes, unsigned int n)
 	{
 	if ( ! escape )
-	    {
-	    AddBytesRaw(bytes, n);
-	    return;
-	    }
+		{
+		AddBytesRaw(bytes, n);
+		return;
+		}
 
-	const char* s = (const char*) bytes;
-	const char* e = (const char*) bytes + n;
+	const char* s = (const char*)bytes;
+	const char* e = (const char*)bytes + n;
 
 	while ( s < e )
 		{
-		std::pair<const char*, size_t> p = FirstEscapeLoc(s, e - s);
+		auto [esc_start, esc_len] = FirstEscapeLoc(s, e - s);
 
-		if ( p.first )
+		if ( esc_start != nullptr )
 			{
-			AddBytesRaw(s, p.first - s);
-			util::get_escaped_string(this, p.first, p.second, true);
-			s = p.first + p.second;
+			if ( utf8 )
+				{
+				std::string result = util::json_escape_utf8(s, esc_start - s, false);
+				AddBytesRaw(result.c_str(), result.size());
+				}
+			else
+				AddBytesRaw(s, esc_start - s);
+
+			util::get_escaped_string(this, esc_start, esc_len, true);
+			s = esc_start + esc_len;
 			}
 		else
 			{
-			AddBytesRaw(s, e - s);
+			if ( utf8 )
+				{
+				std::string result = util::json_escape_utf8(s, e - s, false);
+				AddBytesRaw(result.c_str(), result.size());
+				}
+			else
+				AddBytesRaw(s, e - s);
+
 			break;
 			}
 		}
@@ -356,7 +343,7 @@ void ODesc::AddBytesRaw(const void* bytes, unsigned int n)
 		{
 		static bool write_failed = false;
 
-		if ( ! f->Write((const char*) bytes, n) )
+		if ( ! f->Write((const char*)bytes, n) )
 			{
 			if ( ! write_failed )
 				// Most likely it's a "disk full" so report
@@ -377,10 +364,10 @@ void ODesc::AddBytesRaw(const void* bytes, unsigned int n)
 		// The following casting contortions are necessary because
 		// simply using &base[offset] generates complaints about
 		// using a void* for pointer arithemtic.
-		memcpy((void*) &((char*) base)[offset], bytes, n);
+		memcpy((void*)&((char*)base)[offset], bytes, n);
 		offset += n;
 
-		((char*) base)[offset] = '\0';	// ensure that always NUL-term.
+		((char*)base)[offset] = '\0'; // ensure that always NUL-term.
 		}
 	}
 
@@ -402,7 +389,7 @@ void ODesc::Clear()
 		free(base);
 		size = DEFAULT_SIZE;
 		base = util::safe_malloc(size);
-		((char*) base)[0] = '\0';
+		((char*)base)[0] = '\0';
 		}
 	}
 
@@ -428,7 +415,6 @@ bool ODesc::FindType(const Type* type)
 	return false;
 	}
 
-
 std::string obj_desc(const Obj* o)
 	{
 	static ODesc d;
@@ -441,4 +427,4 @@ std::string obj_desc(const Obj* o)
 	return std::string(d.Description());
 	}
 
-} // namespace zeek
+	} // namespace zeek
