@@ -4,19 +4,18 @@
 
 #include <iostream>
 
-#include "zeek/NetVar.h"
 #include "zeek/Event.h"
-#include "zeek/analyzer/protocol/zip/ZIP.h"
+#include "zeek/NetVar.h"
 #include "zeek/analyzer/Manager.h"
-
 #include "zeek/analyzer/protocol/irc/events.bif.h"
+#include "zeek/analyzer/protocol/zip/ZIP.h"
 
 using namespace std;
 
-namespace zeek::analyzer::irc {
+namespace zeek::analyzer::irc
+	{
 
-IRC_Analyzer::IRC_Analyzer(Connection* conn)
-: analyzer::tcp::TCP_ApplicationAnalyzer("IRC", conn)
+IRC_Analyzer::IRC_Analyzer(Connection* conn) : analyzer::tcp::TCP_ApplicationAnalyzer("IRC", conn)
 	{
 	invalid_msg_count = 0;
 	invalid_msg_max_count = 20;
@@ -64,7 +63,7 @@ void IRC_Analyzer::DeliverStream(int length, const u_char* line, bool orig)
 		return;
 		}
 
-	string myline = string((const char*) line, length);
+	string myline = string((const char*)line, length);
 	SkipLeadingWhitespace(myline);
 
 	if ( myline.length() < 3 )
@@ -85,12 +84,12 @@ void IRC_Analyzer::DeliverStream(int length, const u_char* line, bool orig)
 			}
 
 		prefix = myline.substr(1, pos - 1);
-		myline = myline.substr(pos + 1);  // remove prefix from line
+		myline = myline.substr(pos + 1); // remove prefix from line
 		SkipLeadingWhitespace(myline);
 		}
 
 	if ( orig )
-		ProtocolConfirmation();
+		AnalyzerConfirmation();
 
 	int code = 0;
 	string command = "";
@@ -100,24 +99,22 @@ void IRC_Analyzer::DeliverStream(int length, const u_char* line, bool orig)
 	if ( myline.length() < 3 )
 		{
 		Weird("irc_invalid_line");
-		ProtocolViolation("line too short");
+		AnalyzerViolation("line too short");
 		return;
 		}
 
 	// Check if this is a server reply.
 	if ( isdigit(myline[0]) )
 		{
-		if ( isdigit(myline[1]) && isdigit(myline[2]) &&
-		     myline[3] == ' ')
+		if ( isdigit(myline[1]) && isdigit(myline[2]) && myline[3] == ' ' )
 			{
-			code = (myline[0] - '0') * 100 +
-				(myline[1] - '0') * 10 + (myline[2] - '0');
+			code = (myline[0] - '0') * 100 + (myline[1] - '0') * 10 + (myline[2] - '0');
 			myline = myline.substr(4);
 			}
 		else
 			{
 			Weird("irc_invalid_reply_number");
-			ProtocolViolation("invalid reply number");
+			AnalyzerViolation("invalid reply number");
 			return;
 			}
 		}
@@ -152,13 +149,11 @@ void IRC_Analyzer::DeliverStream(int length, const u_char* line, bool orig)
 		{
 		if ( command == "PASS" )
 			{
-			vector<string> p = SplitWords(params,' ');
-			if ( p.size() > 3 &&
-			     (p[3].find('Z')<=p[3].size() ||
-			      p[3].find('z')<=p[3].size()) )
+			vector<string> p = SplitWords(params, ' ');
+			if ( p.size() > 3 && (p[3].find('Z') <= p[3].size() || p[3].find('z') <= p[3].size()) )
 				orig_zip_status = ACCEPT_ZIP;
 			else
-			        orig_zip_status = NO_ZIP;
+				orig_zip_status = NO_ZIP;
 			}
 
 		// We do not check if SERVER command is successful, since
@@ -166,7 +161,7 @@ void IRC_Analyzer::DeliverStream(int length, const u_char* line, bool orig)
 		// authentication fails.
 		//
 		// (### This seems not quite prudent to me - VP)
-		if ( command == "SERVER" && prefix == "")
+		if ( command == "SERVER" && prefix == "" )
 			{
 			orig_status = REGISTERED;
 			}
@@ -176,416 +171,386 @@ void IRC_Analyzer::DeliverStream(int length, const u_char* line, bool orig)
 		{
 		if ( command == "PASS" )
 			{
-			vector<string> p = SplitWords(params,' ');
-			if ( p.size() > 3 &&
-			     (p[3].find('Z')<=p[3].size() ||
-			      p[3].find('z')<=p[3].size()) )
-			        resp_zip_status = ACCEPT_ZIP;
+			vector<string> p = SplitWords(params, ' ');
+			if ( p.size() > 3 && (p[3].find('Z') <= p[3].size() || p[3].find('z') <= p[3].size()) )
+				resp_zip_status = ACCEPT_ZIP;
 			else
-			        resp_zip_status = NO_ZIP;
-
+				resp_zip_status = NO_ZIP;
 			}
 
 		// Again, don't bother checking whether SERVER command
 		// is successful.
-		if ( command == "SERVER" && prefix == "")
+		if ( command == "SERVER" && prefix == "" )
 			resp_status = REGISTERED;
 		}
 
 	// Analyze server reply messages.
 	if ( code > 0 )
 		{
-		switch ( code ) {
-		/*
-		case 1: // RPL_WELCOME
-		case 2: // RPL_YOURHOST
-		case 3: // RPL_CREATED
-		case 4: // RPL_MYINFO
-		case 5: // RPL_BOUNCE
-		case 252: // number of ops online
-		case 253: // number of unknown connections
-		case 265: // RPL_LOCALUSERS
-		case 312: // whois server reply
-		case 315: // end of who list
-		case 317: // whois idle reply
-		case 318: // end of whois list
-		case 366: // end of names list
-		case 372: // RPL_MOTD
-		case 375: // RPL_MOTDSTART
-		case 376: // RPL_ENDOFMOTD
-		case 331: // RPL_NOTOPIC
-			break;
-		*/
-
-		// Count of users, services and servers in whole network.
-		case 251:
-			if ( ! irc_network_info )
-				break;
-
+		switch ( code )
 			{
-			vector<string> parts = SplitWords(params, ' ');
-			int users = 0;
-			int services = 0;
-			int servers = 0;
+			/*
+			case 1: // RPL_WELCOME
+			case 2: // RPL_YOURHOST
+			case 3: // RPL_CREATED
+			case 4: // RPL_MYINFO
+			case 5: // RPL_BOUNCE
+			case 252: // number of ops online
+			case 253: // number of unknown connections
+			case 265: // RPL_LOCALUSERS
+			case 312: // whois server reply
+			case 315: // end of who list
+			case 317: // whois idle reply
+			case 318: // end of whois list
+			case 366: // end of names list
+			case 372: // RPL_MOTD
+			case 375: // RPL_MOTDSTART
+			case 376: // RPL_ENDOFMOTD
+			case 331: // RPL_NOTOPIC
+				break;
+			*/
 
-			for ( size_t i = 1; i < parts.size(); ++i )
+			// Count of users, services and servers in whole network.
+			case 251:
 				{
-				if ( parts[i] == "users" )
-					users = atoi(parts[i-1].c_str());
-				else if ( parts[i] == "services" )
-					services = atoi(parts[i-1].c_str());
-				else if ( parts[i] == "servers" )
-					servers = atoi(parts[i-1].c_str());
-				// else ###
+				if ( ! irc_network_info )
+					break;
+
+				vector<string> parts = SplitWords(params, ' ');
+				int users = 0;
+				int services = 0;
+				int servers = 0;
+
+				for ( size_t i = 1; i < parts.size(); ++i )
+					{
+					if ( parts[i] == "users" )
+						users = atoi(parts[i - 1].c_str());
+					else if ( parts[i] == "services" )
+						services = atoi(parts[i - 1].c_str());
+					else if ( parts[i] == "servers" )
+						servers = atoi(parts[i - 1].c_str());
+					// else ###
+					}
+
+				EnqueueConnEvent(irc_network_info, ConnVal(), val_mgr->Bool(orig),
+				                 val_mgr->Int(users), val_mgr->Int(services),
+				                 val_mgr->Int(servers));
 				}
-
-			EnqueueConnEvent(irc_network_info,
-			                 ConnVal(),
-			                 val_mgr->Bool(orig),
-			                 val_mgr->Int(users),
-			                 val_mgr->Int(services),
-			                 val_mgr->Int(servers));
-			}
-			break;
-
-		// List of users in a channel (names command).
-		case 353:
-			if ( ! irc_names_info )
 				break;
 
-			{
-			vector<string> parts = SplitWords(params, ' ');
-
-			if ( parts.size() < 3 )
+			// List of users in a channel (names command).
+			case 353:
 				{
-				Weird("irc_invalid_names_line");
-				return;
-				}
+				if ( ! irc_names_info )
+					break;
 
-			// Remove nick name.
-			parts.erase(parts.begin());
+				vector<string> parts = SplitWords(params, ' ');
 
-			string type = parts[0];
-			string channel = parts[1];
+				if ( parts.size() < 3 )
+					{
+					Weird("irc_invalid_names_line");
+					return;
+					}
 
-			// Remove type and channel.
-			parts.erase(parts.begin());
-			parts.erase(parts.begin());
-
-			if ( parts.size() > 0 && parts[0][0] == ':' )
-				parts[0] = parts[0].substr(1);
-
-			auto set = make_intrusive<TableVal>(id::string_set);
-
-			for ( auto& part : parts )
-				{
-				if ( part[0] == '@' )
-					part = part.substr(1);
-				auto idx = make_intrusive<StringVal>(part);
-				set->Assign(std::move(idx), nullptr);
-				}
-
-			EnqueueConnEvent(irc_names_info,
-			                 ConnVal(),
-			                 val_mgr->Bool(orig),
-			                 make_intrusive<StringVal>(type.c_str()),
-			                 make_intrusive<StringVal>(channel.c_str()),
-			                 std::move(set));
-			}
-			break;
-
-		// Count of users and services on this server.
-		case 255:
-			if ( ! irc_server_info )
-				break;
-
-			{
-			vector<string> parts = SplitWords(params, ' ');
-			int users = 0;
-			int services = 0;
-			int servers = 0;
-
-			for ( size_t i = 1; i < parts.size(); ++i )
-				{
-				if ( parts[i] == "users," )
-					users = atoi(parts[i-1].c_str());
-				else if ( parts[i] == "clients" )
-					users = atoi(parts[i-1].c_str());
-				else if ( parts[i] == "services" )
-					services = atoi(parts[i-1].c_str());
-				else if ( parts[i] == "servers" )
-					servers = atoi(parts[i-1].c_str());
-				// else ###
-				}
-
-			EnqueueConnEvent(irc_server_info,
-			                 ConnVal(),
-			                 val_mgr->Bool(orig),
-			                 val_mgr->Int(users),
-			                 val_mgr->Int(services),
-			                 val_mgr->Int(servers));
-			}
-			break;
-
-		// Count of channels.
-		case 254:
-			if ( ! irc_channel_info )
-				break;
-
-			{
-			vector<string> parts = SplitWords(params, ' ');
-			int channels = 0;
-			for ( size_t i = 1; i < parts.size(); ++i )
-				if ( parts[i] == ":channels" )
-					channels = atoi(parts[i - 1].c_str());
-
-			EnqueueConnEvent(irc_channel_info,
-			                 ConnVal(),
-			                 val_mgr->Bool(orig),
-			                 val_mgr->Int(channels));
-			}
-			break;
-
-		// RPL_GLOBALUSERS
-		case 266:
-			{
-			// FIXME: We should really streamline all this
-			// parsing code ...
-			if ( ! irc_global_users )
-				break;
-
-			const char* prefix = params.c_str();
-
-			const char* eop = strchr(prefix, ' ');
-			if ( ! eop )
-				{
-				Weird("invalid_irc_global_users_reply");
-				break;
-				}
-
-			const char *msg = strchr(++eop, ':');
-			if ( ! msg )
-				{
-				Weird("invalid_irc_global_users_reply");
-				break;
-				}
-
-			EnqueueConnEvent(irc_global_users,
-			                 ConnVal(),
-			                 val_mgr->Bool(orig),
-			                 make_intrusive<StringVal>(eop - prefix, prefix),
-			                 make_intrusive<StringVal>(++msg));
-			break;
-			}
-
-		// WHOIS user reply line.
-		case 311:
-			if ( ! irc_whois_user_line )
-				break;
-
-			{
-			vector<string> parts = SplitWords(params, ' ');
-
-			if ( parts.size() > 1 )
-				parts.erase(parts.begin());
-			if ( parts.size() < 5 )
-				{
-				Weird("irc_invalid_whois_user_line");
-				return;
-				}
-
-			Args vl;
-			vl.reserve(6);
-			vl.emplace_back(ConnVal());
-			vl.emplace_back(val_mgr->Bool(orig));
-			vl.emplace_back(make_intrusive<StringVal>(parts[0].c_str()));
-			vl.emplace_back(make_intrusive<StringVal>(parts[1].c_str()));
-			vl.emplace_back(make_intrusive<StringVal>(parts[2].c_str()));
-
-			parts.erase(parts.begin(), parts.begin() + 4);
-
-			string real_name = parts[0];
-			for ( size_t i = 1; i < parts.size(); ++i )
-				real_name = real_name + " " + parts[i];
-
-			if ( real_name[0] == ':' )
-				real_name = real_name.substr(1);
-
-			vl.emplace_back(make_intrusive<StringVal>(real_name.c_str()));
-
-			EnqueueConnEvent(irc_whois_user_line, std::move(vl));
-			}
-			break;
-
-		// WHOIS operator reply line.
-		case 313:
-			if ( ! irc_whois_operator_line )
-				break;
-
-			{
-			vector<string> parts = SplitWords(params, ' ');
-
-			if ( parts.size() > 1 )
+				// Remove nick name.
 				parts.erase(parts.begin());
 
-			if ( parts.size() < 2 )
-				{
-				Weird("irc_invalid_whois_operator_line");
-				return;
+				string type = parts[0];
+				string channel = parts[1];
+
+				// Remove type and channel.
+				parts.erase(parts.begin());
+				parts.erase(parts.begin());
+
+				if ( parts.size() > 0 && parts[0][0] == ':' )
+					parts[0] = parts[0].substr(1);
+
+				auto set = make_intrusive<TableVal>(id::string_set);
+
+				for ( auto& part : parts )
+					{
+					if ( part[0] == '@' )
+						part = part.substr(1);
+					auto idx = make_intrusive<StringVal>(part);
+					set->Assign(std::move(idx), nullptr);
+					}
+
+				EnqueueConnEvent(irc_names_info, ConnVal(), val_mgr->Bool(orig),
+				                 make_intrusive<StringVal>(type.c_str()),
+				                 make_intrusive<StringVal>(channel.c_str()), std::move(set));
 				}
-
-			EnqueueConnEvent(irc_whois_operator_line,
-			                 ConnVal(),
-			                 val_mgr->Bool(orig),
-			                 make_intrusive<StringVal>(parts[0].c_str()));
-			}
-			break;
-
-		// WHOIS channel reply.
-		case 319:
-			if ( ! irc_whois_channel_line )
 				break;
 
-			{
-			vector<string> parts = SplitWords(params, ' ');
-
-			// Remove nick name.
-			parts.erase(parts.begin());
-			if ( parts.size() < 2 )
+			// Count of users and services on this server.
+			case 255:
 				{
-				Weird("irc_invalid_whois_channel_line");
-				return;
+				if ( ! irc_server_info )
+					break;
+
+				vector<string> parts = SplitWords(params, ' ');
+				int users = 0;
+				int services = 0;
+				int servers = 0;
+
+				for ( size_t i = 1; i < parts.size(); ++i )
+					{
+					if ( parts[i] == "users," )
+						users = atoi(parts[i - 1].c_str());
+					else if ( parts[i] == "clients" )
+						users = atoi(parts[i - 1].c_str());
+					else if ( parts[i] == "services" )
+						services = atoi(parts[i - 1].c_str());
+					else if ( parts[i] == "servers" )
+						servers = atoi(parts[i - 1].c_str());
+					// else ###
+					}
+
+				EnqueueConnEvent(irc_server_info, ConnVal(), val_mgr->Bool(orig),
+				                 val_mgr->Int(users), val_mgr->Int(services),
+				                 val_mgr->Int(servers));
 				}
-
-			string nick = parts[0];
-			parts.erase(parts.begin());
-
-			if ( parts.size() > 0 && parts[0][0] == ':' )
-				parts[0] = parts[0].substr(1);
-
-			auto set = make_intrusive<TableVal>(id::string_set);
-
-			for ( const auto& part : parts )
-				{
-				auto idx = make_intrusive<StringVal>(part);
-				set->Assign(std::move(idx), nullptr);
-				}
-
-			EnqueueConnEvent(irc_whois_channel_line,
-			                 ConnVal(),
-			                 val_mgr->Bool(orig),
-			                 make_intrusive<StringVal>(nick.c_str()),
-			                 std::move(set));
-			}
-			break;
-
-		// RPL_TOPIC reply.
-		case 332:
-			{
-			if ( ! irc_channel_topic )
 				break;
 
-			vector<string> parts = SplitWords(params, ' ');
-			if ( parts.size() < 4 )
+			// Count of channels.
+			case 254:
 				{
-				Weird("irc_invalid_topic_reply");
-				return;
+				if ( ! irc_channel_info )
+					break;
+
+				vector<string> parts = SplitWords(params, ' ');
+				int channels = 0;
+				for ( size_t i = 1; i < parts.size(); ++i )
+					if ( parts[i] == ":channels" )
+						channels = atoi(parts[i - 1].c_str());
+
+				EnqueueConnEvent(irc_channel_info, ConnVal(), val_mgr->Bool(orig),
+				                 val_mgr->Int(channels));
 				}
+				break;
 
-			unsigned int pos = params.find(':');
-			if ( pos < params.size() )
+			// RPL_GLOBALUSERS
+			case 266:
 				{
-				string topic = params.substr(pos + 1);
-				const char* t = topic.c_str();
+				// FIXME: We should really streamline all this
+				// parsing code ...
+				if ( ! irc_global_users )
+					break;
 
-				if ( *t == ':' )
-					++t;
+				const char* prefix = params.c_str();
 
-				EnqueueConnEvent(irc_channel_topic,
-				                 ConnVal(),
-				                 val_mgr->Bool(orig),
+				const char* eop = strchr(prefix, ' ');
+				if ( ! eop )
+					{
+					Weird("invalid_irc_global_users_reply");
+					break;
+					}
+
+				const char* msg = strchr(++eop, ':');
+				if ( ! msg )
+					{
+					Weird("invalid_irc_global_users_reply");
+					break;
+					}
+
+				EnqueueConnEvent(irc_global_users, ConnVal(), val_mgr->Bool(orig),
+				                 make_intrusive<StringVal>(eop - prefix, prefix),
+				                 make_intrusive<StringVal>(++msg));
+				}
+				break;
+
+			// WHOIS user reply line.
+			case 311:
+				{
+				if ( ! irc_whois_user_line )
+					break;
+
+				vector<string> parts = SplitWords(params, ' ');
+
+				if ( parts.size() > 1 )
+					parts.erase(parts.begin());
+				if ( parts.size() < 5 )
+					{
+					Weird("irc_invalid_whois_user_line");
+					return;
+					}
+
+				Args vl;
+				vl.reserve(6);
+				vl.emplace_back(ConnVal());
+				vl.emplace_back(val_mgr->Bool(orig));
+				vl.emplace_back(make_intrusive<StringVal>(parts[0].c_str()));
+				vl.emplace_back(make_intrusive<StringVal>(parts[1].c_str()));
+				vl.emplace_back(make_intrusive<StringVal>(parts[2].c_str()));
+
+				parts.erase(parts.begin(), parts.begin() + 4);
+
+				string real_name = parts[0];
+				for ( size_t i = 1; i < parts.size(); ++i )
+					real_name = real_name + " " + parts[i];
+
+				if ( real_name[0] == ':' )
+					real_name = real_name.substr(1);
+
+				vl.emplace_back(make_intrusive<StringVal>(real_name.c_str()));
+
+				EnqueueConnEvent(irc_whois_user_line, std::move(vl));
+				}
+				break;
+
+			// WHOIS operator reply line.
+			case 313:
+				{
+				if ( ! irc_whois_operator_line )
+					break;
+
+				vector<string> parts = SplitWords(params, ' ');
+
+				if ( parts.size() > 1 )
+					parts.erase(parts.begin());
+
+				if ( parts.size() < 2 )
+					{
+					Weird("irc_invalid_whois_operator_line");
+					return;
+					}
+
+				EnqueueConnEvent(irc_whois_operator_line, ConnVal(), val_mgr->Bool(orig),
+				                 make_intrusive<StringVal>(parts[0].c_str()));
+				}
+				break;
+
+			// WHOIS channel reply.
+			case 319:
+				{
+				if ( ! irc_whois_channel_line )
+					break;
+
+				vector<string> parts = SplitWords(params, ' ');
+
+				// Remove nick name.
+				parts.erase(parts.begin());
+				if ( parts.size() < 2 )
+					{
+					Weird("irc_invalid_whois_channel_line");
+					return;
+					}
+
+				string nick = parts[0];
+				parts.erase(parts.begin());
+
+				if ( parts.size() > 0 && parts[0][0] == ':' )
+					parts[0] = parts[0].substr(1);
+
+				auto set = make_intrusive<TableVal>(id::string_set);
+
+				for ( const auto& part : parts )
+					{
+					auto idx = make_intrusive<StringVal>(part);
+					set->Assign(std::move(idx), nullptr);
+					}
+
+				EnqueueConnEvent(irc_whois_channel_line, ConnVal(), val_mgr->Bool(orig),
+				                 make_intrusive<StringVal>(nick.c_str()), std::move(set));
+				}
+				break;
+
+			// RPL_TOPIC reply.
+			case 332:
+				{
+				if ( ! irc_channel_topic )
+					break;
+
+				vector<string> parts = SplitWords(params, ' ');
+				if ( parts.size() < 4 )
+					{
+					Weird("irc_invalid_topic_reply");
+					return;
+					}
+
+				unsigned int pos = params.find(':');
+				if ( pos < params.size() )
+					{
+					string topic = params.substr(pos + 1);
+					const char* t = topic.c_str();
+
+					if ( *t == ':' )
+						++t;
+
+					EnqueueConnEvent(irc_channel_topic, ConnVal(), val_mgr->Bool(orig),
+					                 make_intrusive<StringVal>(parts[1].c_str()),
+					                 make_intrusive<StringVal>(t));
+					}
+				else
+					{
+					Weird("irc_invalid_topic_reply");
+					return;
+					}
+				}
+				break;
+
+			// WHO reply line.
+			case 352:
+				{
+				if ( ! irc_who_line )
+					break;
+
+				vector<string> parts = SplitWords(params, ' ');
+				if ( parts.size() < 9 )
+					{
+					Weird("irc_invalid_who_line");
+					return;
+					}
+
+				if ( parts[2][0] == '~' )
+					parts[2] = parts[2].substr(1);
+
+				if ( parts[7][0] == ':' )
+					parts[7] = parts[7].substr(1);
+
+				EnqueueConnEvent(irc_who_line, ConnVal(), val_mgr->Bool(orig),
+				                 make_intrusive<StringVal>(parts[0].c_str()),
 				                 make_intrusive<StringVal>(parts[1].c_str()),
-				                 make_intrusive<StringVal>(t));
+				                 make_intrusive<StringVal>(parts[2].c_str()),
+				                 make_intrusive<StringVal>(parts[3].c_str()),
+				                 make_intrusive<StringVal>(parts[4].c_str()),
+				                 make_intrusive<StringVal>(parts[5].c_str()),
+				                 make_intrusive<StringVal>(parts[6].c_str()),
+				                 val_mgr->Int(atoi(parts[7].c_str())),
+				                 make_intrusive<StringVal>(parts[8].c_str()));
 				}
-			else
-				{
-				Weird("irc_invalid_topic_reply");
-				return;
-				}
-			break;
-			}
-
-		// WHO reply line.
-		case 352:
-			if ( ! irc_who_line )
 				break;
 
-			{
-			vector<string> parts = SplitWords(params, ' ');
-			if ( parts.size() < 9 )
-				{
-				Weird("irc_invalid_who_line");
-				return;
-				}
+			// Invalid nick name.
+			case 431:
+			case 432:
+			case 433:
+			case 436:
+				if ( irc_invalid_nick )
+					EnqueueConnEvent(irc_invalid_nick, ConnVal(), val_mgr->Bool(orig));
+				break;
 
-			if ( parts[2][0] == '~' )
-				parts[2] = parts[2].substr(1);
+			// Operator responses.
+			case 381: // User is operator
+			case 491: // user is not operator
+				if ( irc_oper_response )
+					EnqueueConnEvent(irc_oper_response, ConnVal(), val_mgr->Bool(orig),
+					                 val_mgr->Bool(code == 381));
+				break;
 
-			if ( parts[7][0] == ':' )
-				parts[7] = parts[7].substr(1);
+			case 670:
+				// StartTLS success reply to StartTLS
+				StartTLS();
+				break;
 
-			EnqueueConnEvent(irc_who_line,
-			                 ConnVal(),
-			                 val_mgr->Bool(orig),
-			                 make_intrusive<StringVal>(parts[0].c_str()),
-			                 make_intrusive<StringVal>(parts[1].c_str()),
-			                 make_intrusive<StringVal>(parts[2].c_str()),
-			                 make_intrusive<StringVal>(parts[3].c_str()),
-			                 make_intrusive<StringVal>(parts[4].c_str()),
-			                 make_intrusive<StringVal>(parts[5].c_str()),
-			                 make_intrusive<StringVal>(parts[6].c_str()),
-			                 val_mgr->Int(atoi(parts[7].c_str())),
-			                 make_intrusive<StringVal>(parts[8].c_str()));
+			// All other server replies.
+			default:
+				if ( irc_reply )
+					EnqueueConnEvent(irc_reply, ConnVal(), val_mgr->Bool(orig),
+					                 make_intrusive<StringVal>(prefix.c_str()),
+					                 val_mgr->Count(code),
+					                 make_intrusive<StringVal>(params.c_str()));
+				break;
 			}
-			break;
-
-		// Invalid nick name.
-		case 431:
-		case 432:
-		case 433:
-		case 436:
-			if ( irc_invalid_nick )
-				EnqueueConnEvent(irc_invalid_nick,
-				                 ConnVal(),
-				                 val_mgr->Bool(orig));
-			break;
-
-		// Operator responses.
-		case 381:  // User is operator
-		case 491:  // user is not operator
-			if ( irc_oper_response )
-				EnqueueConnEvent(irc_oper_response,
-				                 ConnVal(),
-				                 val_mgr->Bool(orig),
-				                 val_mgr->Bool(code == 381));
-			break;
-
-		case 670:
-			// StartTLS success reply to StartTLS
-			StartTLS();
-			break;
-
-		// All other server replies.
-		default:
-			if ( irc_reply )
-				EnqueueConnEvent(irc_reply,
-				                 ConnVal(),
-				                 val_mgr->Bool(orig),
-				                 make_intrusive<StringVal>(prefix.c_str()),
-				                 val_mgr->Count(code),
-				                 make_intrusive<StringVal>(params.c_str()));
-			break;
-		}
 		return;
 		}
 
@@ -596,13 +561,13 @@ void IRC_Analyzer::DeliverStream(int length, const u_char* line, bool orig)
 		if ( ++invalid_msg_count > invalid_msg_max_count )
 			{
 			Weird("irc_too_many_invalid");
-			ProtocolViolation("too many long lines");
+			AnalyzerViolation("too many long lines");
 			return;
 			}
 		return;
 		}
 
-	else if ( ( irc_privmsg_message || irc_dcc_message ) && command == "PRIVMSG")
+	else if ( (irc_privmsg_message || irc_dcc_message) && command == "PRIVMSG" )
 		{
 		unsigned int pos = params.find(' ');
 		if ( pos >= params.size() )
@@ -623,8 +588,7 @@ void IRC_Analyzer::DeliverStream(int length, const u_char* line, bool orig)
 		// Check for DCC messages.
 		if ( message.size() > 3 && message.substr(0, 3) == "DCC" )
 			{
-			if ( message.size() > 0 &&
-			     message[message.size() - 1] == 1 )
+			if ( message.size() > 0 && message[message.size() - 1] == 1 )
 				message = message.substr(0, message.size() - 1);
 
 			vector<string> parts = SplitWords(message, ' ');
@@ -646,31 +610,24 @@ void IRC_Analyzer::DeliverStream(int length, const u_char* line, bool orig)
 				raw_ip = (10 * raw_ip) + atoi(s.c_str());
 				}
 
-
 			if ( irc_dcc_message )
-				EnqueueConnEvent(irc_dcc_message,
-				                 ConnVal(),
-				                 val_mgr->Bool(orig),
-				                 make_intrusive<StringVal>(prefix.c_str()),
-				                 make_intrusive<StringVal>(target.c_str()),
-				                 make_intrusive<StringVal>(parts[1].c_str()),
-				                 make_intrusive<StringVal>(parts[2].c_str()),
-				                 make_intrusive<AddrVal>(htonl(raw_ip)),
-				                 val_mgr->Count(atoi(parts[4].c_str())),
-				                 parts.size() >= 6 ? val_mgr->Count(atoi(parts[5].c_str())) : val_mgr->Count(0)
-					);
+				EnqueueConnEvent(
+					irc_dcc_message, ConnVal(), val_mgr->Bool(orig),
+					make_intrusive<StringVal>(prefix.c_str()),
+					make_intrusive<StringVal>(target.c_str()),
+					make_intrusive<StringVal>(parts[1].c_str()),
+					make_intrusive<StringVal>(parts[2].c_str()),
+					make_intrusive<AddrVal>(htonl(raw_ip)), val_mgr->Count(atoi(parts[4].c_str())),
+					parts.size() >= 6 ? val_mgr->Count(atoi(parts[5].c_str())) : val_mgr->Count(0));
 			}
 
 		else
 			{
 			if ( irc_privmsg_message )
-				EnqueueConnEvent(irc_privmsg_message,
-				                 ConnVal(),
-				                 val_mgr->Bool(orig),
+				EnqueueConnEvent(irc_privmsg_message, ConnVal(), val_mgr->Bool(orig),
 				                 make_intrusive<StringVal>(prefix.c_str()),
 				                 make_intrusive<StringVal>(target.c_str()),
-				                 make_intrusive<StringVal>(message.c_str())
-				);
+				                 make_intrusive<StringVal>(message.c_str()));
 			}
 		}
 
@@ -689,13 +646,10 @@ void IRC_Analyzer::DeliverStream(int length, const u_char* line, bool orig)
 		if ( message[0] == ':' )
 			message = message.substr(1);
 
-		EnqueueConnEvent(irc_notice_message,
-		                 ConnVal(),
-		                 val_mgr->Bool(orig),
+		EnqueueConnEvent(irc_notice_message, ConnVal(), val_mgr->Bool(orig),
 		                 make_intrusive<StringVal>(prefix.c_str()),
 		                 make_intrusive<StringVal>(target.c_str()),
-		                 make_intrusive<StringVal>(message.c_str())
-		);
+		                 make_intrusive<StringVal>(message.c_str()));
 		}
 
 	else if ( irc_squery_message && command == "SQUERY" )
@@ -713,13 +667,10 @@ void IRC_Analyzer::DeliverStream(int length, const u_char* line, bool orig)
 		if ( message[0] == ':' )
 			message = message.substr(1);
 
-		EnqueueConnEvent(irc_squery_message,
-		                 ConnVal(),
-		                 val_mgr->Bool(orig),
+		EnqueueConnEvent(irc_squery_message, ConnVal(), val_mgr->Bool(orig),
 		                 make_intrusive<StringVal>(prefix.c_str()),
 		                 make_intrusive<StringVal>(target.c_str()),
-		                 make_intrusive<StringVal>(message.c_str())
-		);
+		                 make_intrusive<StringVal>(message.c_str()));
 		}
 
 	else if ( irc_user_message && command == "USER" )
@@ -733,15 +684,18 @@ void IRC_Analyzer::DeliverStream(int length, const u_char* line, bool orig)
 
 		if ( parts.size() > 0 )
 			vl.emplace_back(make_intrusive<StringVal>(parts[0].c_str()));
-		else vl.emplace_back(val_mgr->EmptyString());
+		else
+			vl.emplace_back(val_mgr->EmptyString());
 
 		if ( parts.size() > 1 )
 			vl.emplace_back(make_intrusive<StringVal>(parts[1].c_str()));
-		else vl.emplace_back(val_mgr->EmptyString());
+		else
+			vl.emplace_back(val_mgr->EmptyString());
 
 		if ( parts.size() > 2 )
 			vl.emplace_back(make_intrusive<StringVal>(parts[2].c_str()));
-		else vl.emplace_back(val_mgr->EmptyString());
+		else
+			vl.emplace_back(val_mgr->EmptyString());
 
 		string realname;
 		for ( size_t i = 3; i < parts.size(); i++ )
@@ -762,12 +716,9 @@ void IRC_Analyzer::DeliverStream(int length, const u_char* line, bool orig)
 		// extract username and password
 		vector<string> parts = SplitWords(params, ' ');
 		if ( parts.size() == 2 )
-			EnqueueConnEvent(irc_oper_message,
-			                 ConnVal(),
-			                 val_mgr->Bool(orig),
+			EnqueueConnEvent(irc_oper_message, ConnVal(), val_mgr->Bool(orig),
 			                 make_intrusive<StringVal>(parts[0].c_str()),
-			                 make_intrusive<StringVal>(parts[1].c_str())
-			);
+			                 make_intrusive<StringVal>(parts[1].c_str()));
 
 		else
 			Weird("irc_invalid_oper_message_format");
@@ -852,11 +803,7 @@ void IRC_Analyzer::DeliverStream(int length, const u_char* line, bool orig)
 			list->Assign(std::move(info), nullptr);
 			}
 
-		EnqueueConnEvent(irc_join_message,
-			ConnVal(),
-			val_mgr->Bool(orig),
-			std::move(list)
-		);
+		EnqueueConnEvent(irc_join_message, ConnVal(), val_mgr->Bool(orig), std::move(list));
 		}
 
 	else if ( irc_join_message && command == "NJOIN" )
@@ -912,11 +859,7 @@ void IRC_Analyzer::DeliverStream(int length, const u_char* line, bool orig)
 			list->Assign(std::move(info), nullptr);
 			}
 
-		EnqueueConnEvent(irc_join_message,
-			ConnVal(),
-			val_mgr->Bool(orig),
-			std::move(list)
-		);
+		EnqueueConnEvent(irc_join_message, ConnVal(), val_mgr->Bool(orig), std::move(list));
 		}
 
 	else if ( irc_part_message && command == "PART" )
@@ -951,13 +894,9 @@ void IRC_Analyzer::DeliverStream(int length, const u_char* line, bool orig)
 			set->Assign(std::move(idx), nullptr);
 			}
 
-		EnqueueConnEvent(irc_part_message,
-		                 ConnVal(),
-		                 val_mgr->Bool(orig),
-		                 make_intrusive<StringVal>(nick.c_str()),
-		                 std::move(set),
-		                 make_intrusive<StringVal>(message.c_str())
-		);
+		EnqueueConnEvent(irc_part_message, ConnVal(), val_mgr->Bool(orig),
+		                 make_intrusive<StringVal>(nick.c_str()), std::move(set),
+		                 make_intrusive<StringVal>(message.c_str()));
 		}
 
 	else if ( irc_quit_message && command == "QUIT" )
@@ -974,12 +913,9 @@ void IRC_Analyzer::DeliverStream(int length, const u_char* line, bool orig)
 				nickname = prefix.substr(0, pos);
 			}
 
-		EnqueueConnEvent(irc_quit_message,
-		                 ConnVal(),
-		                 val_mgr->Bool(orig),
+		EnqueueConnEvent(irc_quit_message, ConnVal(), val_mgr->Bool(orig),
 		                 make_intrusive<StringVal>(nickname.c_str()),
-		                 make_intrusive<StringVal>(message.c_str())
-		);
+		                 make_intrusive<StringVal>(message.c_str()));
 		}
 
 	else if ( irc_nick_message && command == "NICK" )
@@ -988,12 +924,9 @@ void IRC_Analyzer::DeliverStream(int length, const u_char* line, bool orig)
 		if ( nick[0] == ':' )
 			nick = nick.substr(1);
 
-		EnqueueConnEvent(irc_nick_message,
-		                 ConnVal(),
-		                 val_mgr->Bool(orig),
+		EnqueueConnEvent(irc_nick_message, ConnVal(), val_mgr->Bool(orig),
 		                 make_intrusive<StringVal>(prefix.c_str()),
-		                 make_intrusive<StringVal>(nick.c_str())
-		);
+		                 make_intrusive<StringVal>(nick.c_str()));
 		}
 
 	else if ( irc_who_message && command == "WHO" )
@@ -1013,14 +946,10 @@ void IRC_Analyzer::DeliverStream(int length, const u_char* line, bool orig)
 		if ( parts.size() > 0 && parts[0].size() > 0 && parts[0][0] == ':' )
 			parts[0] = parts[0].substr(1);
 
-		EnqueueConnEvent(irc_who_message,
-		                 ConnVal(),
-		                 val_mgr->Bool(orig),
-		                 parts.size() > 0 ?
-		                 make_intrusive<StringVal>(parts[0].c_str()) :
-		                 val_mgr->EmptyString(),
-		                 val_mgr->Bool(oper)
-		);
+		EnqueueConnEvent(irc_who_message, ConnVal(), val_mgr->Bool(orig),
+		                 parts.size() > 0 ? make_intrusive<StringVal>(parts[0].c_str())
+		                                  : val_mgr->EmptyString(),
+		                 val_mgr->Bool(oper));
 		}
 
 	else if ( irc_whois_message && command == "WHOIS" )
@@ -1043,12 +972,9 @@ void IRC_Analyzer::DeliverStream(int length, const u_char* line, bool orig)
 		else
 			users = parts[0];
 
-		EnqueueConnEvent(irc_whois_message,
-		                 ConnVal(),
-		                 val_mgr->Bool(orig),
+		EnqueueConnEvent(irc_whois_message, ConnVal(), val_mgr->Bool(orig),
 		                 make_intrusive<StringVal>(server.c_str()),
-		                 make_intrusive<StringVal>(users.c_str())
-		);
+		                 make_intrusive<StringVal>(users.c_str()));
 		}
 
 	else if ( irc_error_message && command == "ERROR" )
@@ -1056,12 +982,9 @@ void IRC_Analyzer::DeliverStream(int length, const u_char* line, bool orig)
 		if ( params[0] == ':' )
 			params = params.substr(1);
 
-		EnqueueConnEvent(irc_error_message,
-		                 ConnVal(),
-		                 val_mgr->Bool(orig),
+		EnqueueConnEvent(irc_error_message, ConnVal(), val_mgr->Bool(orig),
 		                 make_intrusive<StringVal>(prefix.c_str()),
-		                 make_intrusive<StringVal>(params.c_str())
-		);
+		                 make_intrusive<StringVal>(params.c_str()));
 		}
 
 	else if ( irc_invite_message && command == "INVITE" )
@@ -1072,13 +995,10 @@ void IRC_Analyzer::DeliverStream(int length, const u_char* line, bool orig)
 			if ( parts[1].size() > 0 && parts[1][0] == ':' )
 				parts[1] = parts[1].substr(1);
 
-			EnqueueConnEvent(irc_invite_message,
-			                 ConnVal(),
-			                 val_mgr->Bool(orig),
+			EnqueueConnEvent(irc_invite_message, ConnVal(), val_mgr->Bool(orig),
 			                 make_intrusive<StringVal>(prefix.c_str()),
 			                 make_intrusive<StringVal>(parts[0].c_str()),
-			                 make_intrusive<StringVal>(parts[1].c_str())
-			);
+			                 make_intrusive<StringVal>(parts[1].c_str()));
 			}
 		else
 			Weird("irc_invalid_invite_message_format");
@@ -1087,12 +1007,9 @@ void IRC_Analyzer::DeliverStream(int length, const u_char* line, bool orig)
 	else if ( irc_mode_message && command == "MODE" )
 		{
 		if ( params.size() > 0 )
-			EnqueueConnEvent(irc_mode_message,
-			                 ConnVal(),
-			                 val_mgr->Bool(orig),
+			EnqueueConnEvent(irc_mode_message, ConnVal(), val_mgr->Bool(orig),
 			                 make_intrusive<StringVal>(prefix.c_str()),
-			                 make_intrusive<StringVal>(params.c_str())
-			);
+			                 make_intrusive<StringVal>(params.c_str()));
 
 		else
 			Weird("irc_invalid_mode_message_format");
@@ -1100,11 +1017,8 @@ void IRC_Analyzer::DeliverStream(int length, const u_char* line, bool orig)
 
 	else if ( irc_password_message && command == "PASS" )
 		{
-		EnqueueConnEvent(irc_password_message,
-		                 ConnVal(),
-		                 val_mgr->Bool(orig),
-		                 make_intrusive<StringVal>(params.c_str())
-		);
+		EnqueueConnEvent(irc_password_message, ConnVal(), val_mgr->Bool(orig),
+		                 make_intrusive<StringVal>(params.c_str()));
 		}
 
 	else if ( irc_squit_message && command == "SQUIT" )
@@ -1122,27 +1036,20 @@ void IRC_Analyzer::DeliverStream(int length, const u_char* line, bool orig)
 				message = message.substr(1);
 			}
 
-		EnqueueConnEvent(irc_squit_message,
-		                 ConnVal(),
-		                 val_mgr->Bool(orig),
+		EnqueueConnEvent(irc_squit_message, ConnVal(), val_mgr->Bool(orig),
 		                 make_intrusive<StringVal>(prefix.c_str()),
 		                 make_intrusive<StringVal>(server.c_str()),
-		                 make_intrusive<StringVal>(message.c_str())
-		);
+		                 make_intrusive<StringVal>(message.c_str()));
 		}
 
-
 	else if ( orig )
 		{
 		if ( irc_request )
 			{
-			EnqueueConnEvent(irc_request,
-			                 ConnVal(),
-			                 val_mgr->Bool(orig),
+			EnqueueConnEvent(irc_request, ConnVal(), val_mgr->Bool(orig),
 			                 make_intrusive<StringVal>(prefix.c_str()),
 			                 make_intrusive<StringVal>(command.c_str()),
-			                 make_intrusive<StringVal>(params.c_str())
-			);
+			                 make_intrusive<StringVal>(params.c_str()));
 			}
 		}
 
@@ -1150,18 +1057,15 @@ void IRC_Analyzer::DeliverStream(int length, const u_char* line, bool orig)
 		{
 		if ( irc_message )
 			{
-			EnqueueConnEvent(irc_message,
-			                 ConnVal(),
-			                 val_mgr->Bool(orig),
+			EnqueueConnEvent(irc_message, ConnVal(), val_mgr->Bool(orig),
 			                 make_intrusive<StringVal>(prefix.c_str()),
 			                 make_intrusive<StringVal>(command.c_str()),
-			                 make_intrusive<StringVal>(params.c_str())
-			);
+			                 make_intrusive<StringVal>(params.c_str()));
 			}
 		}
 
-	if ( orig_status == REGISTERED && resp_status == REGISTERED &&
-	     orig_zip_status == ACCEPT_ZIP && resp_zip_status == ACCEPT_ZIP )
+	if ( orig_status == REGISTERED && resp_status == REGISTERED && orig_zip_status == ACCEPT_ZIP &&
+	     resp_zip_status == ACCEPT_ZIP )
 		{
 		orig_zip_status = ZIP_LOADED;
 		resp_zip_status = ZIP_LOADED;
@@ -1226,4 +1130,4 @@ vector<string> IRC_Analyzer::SplitWords(const string& input, char split)
 	return words;
 	}
 
-} // namespace zeek::analyzer::irc
+	} // namespace zeek::analyzer::irc
