@@ -3,59 +3,67 @@
 #include <assert.h>
 #include <openssl/evp.h>
 #include <stdio.h>
-#include <vector>
 #include <queue>
+#include <vector>
 
-#include "zeek/ZeekString.h"
 #include "zeek/Reporter.h"
+#include "zeek/ZeekString.h"
 #include "zeek/analyzer/Analyzer.h"
 
-namespace zeek {
+namespace zeek
+	{
 
 class TableVal;
 class StringVal;
 using TableValPtr = IntrusivePtr<TableVal>;
 using StringValPtr = IntrusivePtr<StringVal>;
 
-namespace detail { class Base64Converter; }
+namespace detail
+	{
+class Base64Converter;
+	}
 
-namespace analyzer::mime {
+namespace analyzer::mime
+	{
 
-// MIME: Multipurpose Internet Mail Extensions
-// Follows RFC 822 & 2822 (Internet Mail), 2045-2049 (MIME)
-// See related files: SMTP.h and SMTP.cc
+	// MIME: Multipurpose Internet Mail Extensions
+	// Follows RFC 822 & 2822 (Internet Mail), 2045-2049 (MIME)
+	// See related files: SMTP.h and SMTP.cc
 
-// MIME Constants
+	// MIME Constants
 
-#define HT	'\011'
-#define SP	'\040'
-#define CR	'\015'
-#define LF	'\012'
+#define HT '\011'
+#define SP '\040'
+#define CR '\015'
+#define LF '\012'
 
-enum MIME_CONTENT_TYPE {
+enum MIME_CONTENT_TYPE
+	{
 	CONTENT_TYPE_MULTIPART,
 	CONTENT_TYPE_MESSAGE,
 	CONTENT_TYPE_TEXT,
-	CONTENT_TYPE_OTHER,	// image | audio | video | application | <other>
-};
+	CONTENT_TYPE_OTHER, // image | audio | video | application | <other>
+	};
 
-enum MIME_EVENT_TYPE {
+enum MIME_EVENT_TYPE
+	{
 	MIME_EVENT_ILLEGAL_FORMAT,
 	MIME_EVENT_ILLEGAL_ENCODING,
 	MIME_EVENT_CONTENT_GAP,
 	MIME_EVENT_OTHER,
-};
+	};
 
 // MIME data structures.
 
 class MIME_Multiline;
 class MIME_Header;
 class MIME_Body;
-class MIME_Entity;	// an "entity" contains headers and a body
+class MIME_Entity; // an "entity" contains headers and a body
 class MIME_Mail;
 class MIME_Message;
 
-class MIME_Multiline {
+class MIME_Multiline
+	{
 public:
 	MIME_Multiline();
 	~MIME_Multiline();
@@ -66,15 +74,16 @@ public:
 protected:
 	std::vector<const String*> buffer;
 	String* line;
-};
+	};
 
-class MIME_Header {
+class MIME_Header
+	{
 public:
 	explicit MIME_Header(MIME_Multiline* hl);
 	~MIME_Header();
 
-	data_chunk_t get_name() const	{ return name; }
-	data_chunk_t get_value() const	{ return value; }
+	data_chunk_t get_name() const { return name; }
+	data_chunk_t get_value() const { return value; }
 
 	data_chunk_t get_value_token();
 	data_chunk_t get_value_after_token();
@@ -86,12 +95,12 @@ protected:
 	data_chunk_t name;
 	data_chunk_t value;
 	data_chunk_t value_token, rest_value;
-};
-
+	};
 
 using MIME_HeaderList = std::vector<MIME_Header*>;
 
-class MIME_Entity {
+class MIME_Entity
+	{
 public:
 	MIME_Entity(MIME_Message* output_message, MIME_Entity* parent_entity);
 	virtual ~MIME_Entity();
@@ -178,13 +187,14 @@ protected:
 	MIME_Message* message;
 	bool delay_adding_implicit_CRLF;
 	bool want_all_headers;
-};
+	};
 
 // The reason I separate MIME_Message as an abstract class is to
 // present the *interface* separated from its implementation to
 // generate Bro events.
 
-class MIME_Message {
+class MIME_Message
+	{
 public:
 	explicit MIME_Message(analyzer::Analyzer* arg_analyzer)
 		{
@@ -199,20 +209,19 @@ public:
 	virtual ~MIME_Message()
 		{
 		if ( ! finished )
-			reporter->AnalyzerError(analyzer,
-			                              "missing MIME_Message::Done() call");
+			reporter->AnalyzerError(analyzer, "missing MIME_Message::Done() call");
 		}
 
-	virtual void Done()	{ finished = true; }
+	virtual void Done() { finished = true; }
 
-	bool Finished() const	{ return finished; }
+	bool Finished() const { return finished; }
 
 	virtual void Deliver(int len, const char* data, bool trailing_CRLF)
 		{
 		top_level->Deliver(len, data, trailing_CRLF);
 		}
 
-	analyzer::Analyzer* GetAnalyzer() const	{ return analyzer; }
+	analyzer::Analyzer* GetAnalyzer() const { return analyzer; }
 
 	// Events generated by MIME_Entity
 	virtual void BeginEntity(MIME_Entity*) = 0;
@@ -231,9 +240,10 @@ protected:
 
 	RecordValPtr ToHeaderVal(MIME_Header* h);
 	TableValPtr ToHeaderTable(MIME_HeaderList& hlist);
-};
+	};
 
-class MIME_Mail final : public MIME_Message {
+class MIME_Mail final : public MIME_Message
+	{
 public:
 	MIME_Mail(analyzer::Analyzer* mail_conn, bool is_orig, int buf_size = 0);
 	~MIME_Mail() override;
@@ -265,7 +275,7 @@ protected:
 
 	uint64_t cur_entity_len;
 	std::string cur_entity_id;
-};
+	};
 
 extern bool is_null_data_chunk(data_chunk_t b);
 extern StringValPtr to_string_val(int length, const char* data);
@@ -279,13 +289,12 @@ extern int MIME_count_leading_lws(int len, const char* data);
 extern int MIME_count_trailing_lws(int len, const char* data);
 extern int MIME_skip_comments(int len, const char* data);
 extern int MIME_skip_lws_comments(int len, const char* data);
-extern int MIME_get_token(int len, const char* data, data_chunk_t* token,
-                          bool is_boundary = false);
-extern int MIME_get_slash_token_pair(int len, const char* data, data_chunk_t* first, data_chunk_t* second);
-extern int MIME_get_value(int len, const char* data, String*& buf,
-                          bool is_boundary = false);
+extern int MIME_get_token(int len, const char* data, data_chunk_t* token, bool is_boundary = false);
+extern int MIME_get_slash_token_pair(int len, const char* data, data_chunk_t* first,
+                                     data_chunk_t* second);
+extern int MIME_get_value(int len, const char* data, String*& buf, bool is_boundary = false);
 extern int MIME_get_field_name(int len, const char* data, data_chunk_t* name);
 extern String* MIME_decode_quoted_pairs(data_chunk_t buf);
 
-} // namespace analyzer::mime
-} // namespace zeek
+	} // namespace analyzer::mime
+	} // namespace zeek
