@@ -1,14 +1,14 @@
 #include "zeek/analyzer/protocol/rdp/RDP.h"
-#include "zeek/analyzer/protocol/tcp/TCP_Reassembler.h"
-#include "zeek/Reporter.h"
 
+#include "zeek/Reporter.h"
 #include "zeek/analyzer/protocol/rdp/events.bif.h"
 #include "zeek/analyzer/protocol/rdp/types.bif.h"
+#include "zeek/analyzer/protocol/tcp/TCP_Reassembler.h"
 
-namespace zeek::analyzer::rdp {
+namespace zeek::analyzer::rdp
+	{
 
-RDP_Analyzer::RDP_Analyzer(Connection* c)
-	: analyzer::tcp::TCP_ApplicationAnalyzer("RDP", c)
+RDP_Analyzer::RDP_Analyzer(Connection* c) : analyzer::tcp::TCP_ApplicationAnalyzer("RDP", c)
 	{
 	interp = new binpac::RDP::RDP_Conn(this);
 
@@ -61,8 +61,7 @@ void RDP_Analyzer::DeliverStream(int len, const u_char* data, bool orig)
 
 				if ( ! AddChildAnalyzer(pia) )
 					{
-					reporter->AnalyzerError(this,
-					                              "failed to add TCP child analyzer "
+					reporter->AnalyzerError(this, "failed to add TCP child analyzer "
 					                              "to RDP analyzer: already exists");
 					return;
 					}
@@ -77,8 +76,7 @@ void RDP_Analyzer::DeliverStream(int len, const u_char* data, bool orig)
 			{
 			if ( rdp_native_encrypted_data )
 				BifEvent::enqueue_rdp_native_encrypted_data(
-				        interp->zeek_analyzer(), interp->zeek_analyzer()->Conn(),
-				        orig, len);
+					interp->zeek_analyzer(), interp->zeek_analyzer()->Conn(), orig, len);
 			}
 		}
 	else // if not encrypted
@@ -89,7 +87,7 @@ void RDP_Analyzer::DeliverStream(int len, const u_char* data, bool orig)
 			}
 		catch ( const binpac::Exception& e )
 			{
-			ProtocolViolation(util::fmt("Binpac exception: %s", e.c_msg()));
+			AnalyzerViolation(util::fmt("Binpac exception: %s", e.c_msg()));
 			}
 		}
 	}
@@ -101,4 +99,4 @@ void RDP_Analyzer::Undelivered(uint64_t seq, int len, bool orig)
 	interp->NewGap(orig, len);
 	}
 
-} // namespace zeek::analyzer::rdp
+	} // namespace zeek::analyzer::rdp
