@@ -1,19 +1,20 @@
 // See the file  in the main distribution directory for copyright.
 
-#include "zeek/zeek-config.h"
 #include "zeek/iosource/pcap/Source.h"
 
+#include "zeek/zeek-config.h"
+
 #ifdef HAVE_PCAP_INT_H
 #include <pcap-int.h>
 #endif
 
-#include "zeek/iosource/Packet.h"
-#include "zeek/iosource/BPF_Program.h"
 #include "zeek/Event.h"
-
+#include "zeek/iosource/BPF_Program.h"
+#include "zeek/iosource/Packet.h"
 #include "zeek/iosource/pcap/pcap.bif.h"
 
-namespace zeek::iosource::pcap {
+namespace zeek::iosource::pcap
+	{
 
 PcapSource::~PcapSource()
 	{
@@ -156,7 +157,7 @@ void PcapSource::OpenLive()
 #endif
 
 #ifdef HAVE_PCAP_INT_H
-	Info(util::fmt("pcap bufsize = %d\n", ((struct pcap *) pd)->bufsize));
+	Info(util::fmt("pcap bufsize = %d\n", ((struct pcap*)pd)->bufsize));
 #endif
 
 	props.selectable_fd = pcap_get_selectable_fd(pd);
@@ -200,39 +201,40 @@ bool PcapSource::ExtractNextPacket(Packet* pkt)
 
 	int res = pcap_next_ex(pd, &header, &data);
 
-	switch ( res ) {
-	case PCAP_ERROR_BREAK: // -2
-		// Exhausted pcap file, no more packets to read.
-		assert(! props.is_live);
-		Close();
-		return false;
-	case PCAP_ERROR: // -1
-		// Error occurred while reading the packet.
-		if ( props.is_live )
-			reporter->Error("failed to read a packet from %s: %s",
-			                props.path.data(), pcap_geterr(pd));
-		else
-			reporter->FatalError("failed to read a packet from %s: %s",
-			                     props.path.data(), pcap_geterr(pd));
-		return false;
-	case 0:
-		// Read from live interface timed out (ok).
-		return false;
-	case 1:
-		// Read a packet without problem.
-		// Although, some libpcaps may claim to have read a packet, but either did
-		// not really read a packet or at least provide no way to access its
-		// contents, so the following check for null-data helps handle those cases.
-		if ( ! data )
-			{
-			reporter->Weird("pcap_null_data_packet");
+	switch ( res )
+		{
+		case PCAP_ERROR_BREAK: // -2
+			// Exhausted pcap file, no more packets to read.
+			assert(! props.is_live);
+			Close();
 			return false;
-			}
-		break;
-	default:
-		reporter->InternalError("unhandled pcap_next_ex return value: %d", res);
-		return false;
-	}
+		case PCAP_ERROR: // -1
+			// Error occurred while reading the packet.
+			if ( props.is_live )
+				reporter->Error("failed to read a packet from %s: %s", props.path.data(),
+				                pcap_geterr(pd));
+			else
+				reporter->FatalError("failed to read a packet from %s: %s", props.path.data(),
+				                     pcap_geterr(pd));
+			return false;
+		case 0:
+			// Read from live interface timed out (ok).
+			return false;
+		case 1:
+			// Read a packet without problem.
+			// Although, some libpcaps may claim to have read a packet, but either did
+			// not really read a packet or at least provide no way to access its
+			// contents, so the following check for null-data helps handle those cases.
+			if ( ! data )
+				{
+				reporter->Weird("pcap_null_data_packet");
+				return false;
+				}
+			break;
+		default:
+			reporter->InternalError("unhandled pcap_next_ex return value: %d", res);
+			return false;
+		}
 
 	pkt->Init(props.link_type, &header->ts, header->caplen, header->len, data);
 
@@ -245,6 +247,14 @@ bool PcapSource::ExtractNextPacket(Packet* pkt)
 	++stats.received;
 	stats.bytes_received += header->len;
 
+	// Some versions of libpcap (myricom) are somewhat broken and will return a duplicate
+	// packet if there are no more packets available. Namely, it returns the exact same
+	// packet structure (including the header) out of the library without reinitializing
+	// any of the values. If we set the header lengths to zero here, we can keep from
+	// processing it a second time.
+	header->len = 0;
+	header->caplen = 0;
+
 	return true;
 	}
 
@@ -269,9 +279,7 @@ bool PcapSource::SetFilter(int index)
 
 	if ( ! code )
 		{
-		snprintf(errbuf, sizeof(errbuf),
-			      "No precompiled pcap filter for index %d",
-			      index);
+		snprintf(errbuf, sizeof(errbuf), "No precompiled pcap filter for index %d", index);
 		Error(errbuf);
 		return false;
 		}
@@ -350,4 +358,4 @@ iosource::PktSrc* PcapSource::Instantiate(const std::string& path, bool is_live)
 	return new PcapSource(path, is_live);
 	}
 
-} // namespace zeek::iosource::pcap
+	} // namespace zeek::iosource::pcap
