@@ -4,17 +4,18 @@
 
 #include <pcap.h> // For DLT_ constants
 
-#include "zeek/RunState.h"
+#include "zeek/Conn.h"
 #include "zeek/IP.h"
+#include "zeek/RunState.h"
 #include "zeek/TunnelEncapsulation.h"
 #include "zeek/packet_analysis/protocol/ip/IP.h"
 
-namespace zeek::packet_analysis::IPTunnel {
+namespace zeek::packet_analysis::IPTunnel
+	{
 
 IPTunnelAnalyzer* ip_tunnel_analyzer;
 
-IPTunnelAnalyzer::IPTunnelAnalyzer()
-	: zeek::packet_analysis::Analyzer("IPTunnel")
+IPTunnelAnalyzer::IPTunnelAnalyzer() : zeek::packet_analysis::Analyzer("IPTunnel")
 	{
 	ip_tunnel_analyzer = this;
 	}
@@ -23,7 +24,7 @@ bool IPTunnelAnalyzer::AnalyzePacket(size_t len, const uint8_t* data, Packet* pa
 	{
 	if ( ! packet->ip_hdr )
 		{
-		reporter->InternalError("IPTunnelAnalyzer: ip_hdr not found in packet keystore");
+		reporter->InternalError("IPTunnelAnalyzer: null ip_hdr in packet");
 		return false;
 		}
 
@@ -33,8 +34,7 @@ bool IPTunnelAnalyzer::AnalyzePacket(size_t len, const uint8_t* data, Packet* pa
 		return false;
 		}
 
-	if ( packet->encap &&
-	     packet->encap->Depth() >= BifConst::Tunnel::max_depth )
+	if ( packet->encap && packet->encap->Depth() >= BifConst::Tunnel::max_depth )
 		{
 		Weird("exceeded_tunnel_max_depth", packet);
 		return false;
@@ -45,7 +45,7 @@ bool IPTunnelAnalyzer::AnalyzePacket(size_t len, const uint8_t* data, Packet* pa
 	BifEnum::Tunnel::Type tunnel_type = packet->tunnel_type;
 	int gre_link_type = packet->gre_link_type;
 
-	std::unique_ptr<IP_Hdr> inner = nullptr;
+	std::shared_ptr<IP_Hdr> inner = nullptr;
 
 	if ( gre_version != 0 )
 		{
@@ -75,29 +75,28 @@ bool IPTunnelAnalyzer::AnalyzePacket(size_t len, const uint8_t* data, Packet* pa
 
 	if ( tunnel_it == ip_tunnels.end() )
 		{
-		EncapsulatingConn ec(packet->ip_hdr->SrcAddr(), packet->ip_hdr->DstAddr(),
-		                     tunnel_type);
+		EncapsulatingConn ec(packet->ip_hdr->SrcAddr(), packet->ip_hdr->DstAddr(), tunnel_type);
 		ip_tunnels[tunnel_idx] = TunnelActivity(ec, run_state::network_time);
-		zeek::detail::timer_mgr->Add(new detail::IPTunnelTimer(run_state::network_time, tunnel_idx, this));
+		zeek::detail::timer_mgr->Add(
+			new detail::IPTunnelTimer(run_state::network_time, tunnel_idx, this));
 		}
 	else
 		tunnel_it->second.second = zeek::run_state::network_time;
 
 	if ( gre_version == 0 )
-		ProcessEncapsulatedPacket(run_state::processing_start_time, packet, len, len, data, gre_link_type,
-		                          packet->encap, ip_tunnels[tunnel_idx].first);
+		return ProcessEncapsulatedPacket(run_state::processing_start_time, packet, len, len, data,
+		                                 gre_link_type, packet->encap,
+		                                 ip_tunnels[tunnel_idx].first);
 	else
-		ProcessEncapsulatedPacket(run_state::processing_start_time, packet, inner, packet->encap,
-		                          ip_tunnels[tunnel_idx].first);
-
-	return true;
+		return ProcessEncapsulatedPacket(run_state::processing_start_time, packet, inner,
+		                                 packet->encap, ip_tunnels[tunnel_idx].first);
 	}
 
 /**
  * Handles a packet that contains an IP header directly after the tunnel header.
  */
 bool IPTunnelAnalyzer::ProcessEncapsulatedPacket(double t, const Packet* pkt,
-                                                 const std::unique_ptr<IP_Hdr>& inner,
+                                                 const std::shared_ptr<IP_Hdr>& inner,
                                                  std::shared_ptr<EncapsulationStack> prev,
                                                  const EncapsulatingConn& ec)
 	{
@@ -111,17 +110,16 @@ bool IPTunnelAnalyzer::ProcessEncapsulatedPacket(double t, const Packet* pkt,
 		ts = pkt->ts;
 	else
 		{
-		ts.tv_sec = (time_t) run_state::network_time;
-		ts.tv_usec = (suseconds_t)
-		    ((run_state::network_time - (double)ts.tv_sec) * 1000000);
+		ts.tv_sec = (time_t)run_state::network_time;
+		ts.tv_usec = (suseconds_t)((run_state::network_time - (double)ts.tv_sec) * 1000000);
 		}
 
 	const u_char* data = nullptr;
 
 	if ( inner->IP4_Hdr() )
-		data = (const u_char*) inner->IP4_Hdr();
+		data = (const u_char*)inner->IP4_Hdr();
 	else
-		data = (const u_char*) inner->IP6_Hdr();
+		data = (const u_char*)inner->IP6_Hdr();
 
 	auto outer = prev ? prev : std::make_shared<EncapsulationStack>();
 	outer->Add(ec);
@@ -141,9 +139,8 @@ bool IPTunnelAnalyzer::ProcessEncapsulatedPacket(double t, const Packet* pkt,
 /**
  * Handles a packet that contains a physical-layer header after the tunnel header.
  */
-bool IPTunnelAnalyzer::ProcessEncapsulatedPacket(double t, const Packet* pkt,
-                                                 uint32_t caplen, uint32_t len,
-                                                 const u_char* data, int link_type,
+bool IPTunnelAnalyzer::ProcessEncapsulatedPacket(double t, const Packet* pkt, uint32_t caplen,
+                                                 uint32_t len, const u_char* data, int link_type,
                                                  std::shared_ptr<EncapsulationStack> prev,
                                                  const EncapsulatingConn& ec)
 	{
@@ -153,9 +150,8 @@ bool IPTunnelAnalyzer::ProcessEncapsulatedPacket(double t, const Packet* pkt,
 		ts = pkt->ts;
 	else
 		{
-		ts.tv_sec = (time_t) run_state::network_time;
-		ts.tv_usec = (suseconds_t)
-		    ((run_state::network_time - (double)ts.tv_sec) * 1000000);
+		ts.tv_sec = (time_t)run_state::network_time;
+		ts.tv_usec = (suseconds_t)((run_state::network_time - (double)ts.tv_sec) * 1000000);
 		}
 
 	auto outer = prev ? prev : std::make_shared<EncapsulationStack>();
@@ -174,19 +170,49 @@ bool IPTunnelAnalyzer::ProcessEncapsulatedPacket(double t, const Packet* pkt,
 	return return_val;
 	}
 
-namespace detail {
+std::unique_ptr<Packet> build_inner_packet(Packet* outer_pkt, int* encap_index,
+                                           std::shared_ptr<EncapsulationStack> encap_stack,
+                                           uint32_t len, const u_char* data, int link_type,
+                                           BifEnum::Tunnel::Type tunnel_type,
+                                           const Tag& analyzer_tag)
+	{
+	auto inner_pkt = std::make_unique<Packet>();
+
+	pkt_timeval ts;
+	ts.tv_sec = static_cast<time_t>(run_state::current_timestamp);
+	ts.tv_usec = static_cast<suseconds_t>(
+		(run_state::current_timestamp - static_cast<double>(ts.tv_sec)) * 1000000);
+	inner_pkt->Init(link_type, &ts, len, len, data);
+
+	*encap_index = 0;
+	if ( outer_pkt->session )
+		{
+		EncapsulatingConn inner(static_cast<Connection*>(outer_pkt->session), tunnel_type);
+
+		if ( ! outer_pkt->encap )
+			outer_pkt->encap = encap_stack != nullptr ? encap_stack
+			                                          : std::make_shared<EncapsulationStack>();
+
+		outer_pkt->encap->Add(inner);
+		inner_pkt->encap = outer_pkt->encap;
+		*encap_index = outer_pkt->encap->Depth();
+		}
+
+	return inner_pkt;
+	}
+
+namespace detail
+	{
 
 IPTunnelTimer::IPTunnelTimer(double t, IPTunnelAnalyzer::IPPair p, IPTunnelAnalyzer* analyzer)
-	: Timer(t + BifConst::Tunnel::ip_tunnel_timeout,
-	        zeek::detail::TIMER_IP_TUNNEL_INACTIVITY),
+	: Timer(t + BifConst::Tunnel::ip_tunnel_timeout, zeek::detail::TIMER_IP_TUNNEL_INACTIVITY),
 	  tunnel_idx(p), analyzer(analyzer)
 	{
 	}
 
 void IPTunnelTimer::Dispatch(double t, bool is_expire)
 	{
-	IPTunnelAnalyzer::IPTunnelMap::const_iterator it =
-		analyzer->ip_tunnels.find(tunnel_idx);
+	IPTunnelAnalyzer::IPTunnelMap::const_iterator it = analyzer->ip_tunnels.find(tunnel_idx);
 
 	if ( it == analyzer->ip_tunnels.end() )
 		return;
@@ -203,6 +229,6 @@ void IPTunnelTimer::Dispatch(double t, bool is_expire)
 		zeek::detail::timer_mgr->Add(new IPTunnelTimer(t, tunnel_idx, analyzer));
 	}
 
-} // namespace detail
+	} // namespace detail
 
-} // namespace zeek::packet_analysis::IPTunnel
+	} // namespace zeek::packet_analysis::IPTunnel
