@@ -1,17 +1,20 @@
 // See the file "COPYING" in the main distribution directory for copyright.
 
 #include "zeek/plugin/Plugin.h"
+
 #include "zeek/packet_analysis/Component.h"
 #include "zeek/packet_analysis/protocol/linux_sll/LinuxSLL.h"
 
-namespace zeek::plugin::Zeek_LinuxSLL {
+namespace zeek::plugin::Zeek_LinuxSLL
+	{
 
-class Plugin : public zeek::plugin::Plugin {
+class Plugin : public zeek::plugin::Plugin
+	{
 public:
 	zeek::plugin::Configuration Configure()
 		{
-		AddComponent(new zeek::packet_analysis::Component("LinuxSLL",
-		                 zeek::packet_analysis::LinuxSLL::LinuxSLLAnalyzer::Instantiate));
+		AddComponent(new zeek::packet_analysis::Component(
+			"LinuxSLL", zeek::packet_analysis::LinuxSLL::LinuxSLLAnalyzer::Instantiate));
 
 		zeek::plugin::Configuration config;
 		config.name = "Zeek::LinuxSLL";
@@ -19,6 +22,6 @@ public:
 		return config;
 		}
 
-} plugin;
+	} plugin;
 
-}
+	}
