@@ -1,13 +1,9 @@
 // See the file "COPYING" in the main distribution directory for copyright.
 
-#include <errno.h>
-#include <unistd.h>
-#include <sys/stat.h>
-
 #include "zeek/script_opt/CPP/Compile.h"
 
-
-namespace zeek::detail {
+namespace zeek::detail
+	{
 
 using namespace std;
 
@@ -31,15 +27,11 @@ void CPPCompile::CompileLambda(const LambdaExpr* l, const ProfileFunc* pf)
 	auto l_id = l->Ingredients().id;
 	auto& ids = l->OuterIDs();
 
-	DefineBody(l_id->GetType<FuncType>(), pf, lname, body, &ids,
-	           FUNC_FLAVOR_FUNCTION);
+	DefineBody(l_id->GetType<FuncType>(), pf, lname, body, &ids, FUNC_FLAVOR_FUNCTION);
 	}
 
-void CPPCompile::GenInvokeBody(const string& fname, const TypePtr& t,
-                               const string& args)
+void CPPCompile::GenInvokeBody(const string& call, const TypePtr& t)
 	{
-	auto call = fname + "(" + args + ")";
-
 	if ( ! t || t->Tag() == TYPE_VOID )
 		{
 		Emit("%s;", call);
@@ -49,9 +41,8 @@ void CPPCompile::GenInvokeBody(const string& fname, const TypePtr& t,
 		Emit("return %s;", NativeToGT(call, t, GEN_VAL_PTR));
 	}
 
-void CPPCompile::DefineBody(const FuncTypePtr& ft, const ProfileFunc* pf,
-                            const string& fname, const StmtPtr& body,
-                            const IDPList* lambda_ids, FunctionFlavor flavor)
+void CPPCompile::DefineBody(const FuncTypePtr& ft, const ProfileFunc* pf, const string& fname,
+                            const StmtPtr& body, const IDPList* lambda_ids, FunctionFlavor flavor)
 	{
 	locals.clear();
 	params.clear();
@@ -147,7 +138,7 @@ void CPPCompile::InitializeEvents(const ProfileFunc* pf)
 		// returns an EventHandlerPtr, sigh.
 		Emit("if ( event_registry->Lookup(\"%s\") )", e);
 		StartBlock();
-		Emit("%s = event_registry->Register(\"%s\");", ev_name.c_str(), e);
+		Emit("%s = event_registry->Register(\"%s\");", ev_name, e);
 		EndBlock();
 		Emit("did_init = true;");
 		EndBlock();
@@ -207,12 +198,18 @@ string CPPCompile::BodyName(const FuncInfo& func)
 		while ( *fn == '.' || *fn == '/' )
 			++fn;
 
-		auto canonicalize =
-			[](char c) -> char { return isalnum(c) ? c : '_'; };
+		auto canonicalize = [](char c) -> char
+		{
+			return isalnum(c) ? c : '_';
+		};
 
 		string fns = fn;
 		transform(fns.begin(), fns.end(), fns.begin(), canonicalize);
 
+		if ( ! isalpha(fns[0]) )
+			// This can happen for filenames beginning with numbers.
+			fns = "_" + fns;
+
 		fname = fns + "__" + fname;
 		}
 
@@ -234,6 +231,18 @@ string CPPCompile::BodyName(const FuncInfo& func)
 	return fname + "__" + Fmt(static_cast<int>(i));
 	}
 
+p_hash_type CPPCompile::BodyHash(const Stmt* body)
+	{
+	auto bn = body_names.find(body);
+	ASSERT(bn != body_names.end());
+
+	auto& body_name = bn->second;
+	auto bh = body_hashes.find(body_name);
+	ASSERT(bh != body_hashes.end());
+
+	return bh->second;
+	}
+
 string CPPCompile::GenArgs(const RecordTypePtr& params, const Expr* e)
 	{
 	const auto& exprs = e->AsListExpr()->Exprs();
@@ -266,4 +275,4 @@ string CPPCompile::GenArgs(const RecordTypePtr& params, const Expr* e)
 	return gen;
 	}
 
-} // zeek::detail
+	} // zeek::detail
